<?php
	/*======
	*
	* Theme After Setup Start
	*
	======*/
	function nucy_setup(){
		load_theme_textdomain( 'nucy', get_template_directory() . '/languages' );
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'title-tag' );
		add_theme_support( 'custom-background' );
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'post-formats', array( 'quote', 'gallery', 'image', 'video', 'audio', 'chat', 'link' ) );
		add_theme_support( 'wc-product-gallery-zoom' );
		add_theme_support( 'wc-product-gallery-lightbox' );
		add_theme_support( 'wc-product-gallery-slider' );

		if( function_exists( 'add_image_size' ) ) { 
			add_image_size( 'nucy-post-1', 740, 470, true );
			add_image_size( 'nucy-feature-box-1', 540, 340, true );
			add_image_size( 'nucy-feature-box-2', 720, 600, true );
			add_image_size( 'nucy-feature-box-3', 1110, 430, true );
			add_image_size( 'nucy-clients', 400, 400, true );
			add_image_size( 'nucy-page-banner', 1900, 400, true );
			add_image_size( 'nucy-history-box', 370, 200, true );
			add_image_size( 'nucy-portfolio-1', 540, 540, true );
			add_image_size( 'nucy-portfolio-2', 1200, 600, true );
			add_image_size( 'nucy-shop-1', 585, 585, true );
			add_image_size( 'nucy-team-1', 540, 450, true );
			add_image_size( 'nucy-slider-1', 1920, 950, true );
		}
		
		if( ! isset( $content_width ) ) {
			$content_width = 600;
		}
		
		if( is_singular() ) wp_enqueue_script( 'comment-reply' );
	}
	add_action( 'after_setup_theme', 'nucy_setup' );



	/*======
	*
	* Theme Scripts & Styles
	*
	======*/
	function nucy_scripts()
	{
		wp_enqueue_script( 'popper', get_template_directory_uri() . '/include/assets/js/popper.min.js', array(), false, true );
		wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/include/assets/js/bootstrap.min.js', array(), false, true );
		wp_enqueue_script( 'jscrollpane', get_template_directory_uri() . '/include/assets/js/jscrollpane.min.js', array(), false, true );
		wp_enqueue_script( 'mousewheel', get_template_directory_uri() . '/include/assets/js/mousewheel.min.js', array(), false, true );
		wp_enqueue_script( 'swiper', get_template_directory_uri() . '/include/assets/js/swiper.min.js', array(), false, true );
		wp_enqueue_script( 'fixed-sidebar', get_template_directory_uri() . '/include/assets/js/fixed-sidebar.js', array(), false, true );
		wp_enqueue_script( 'tweenmax', get_template_directory_uri() . '/include/assets/js/tweenmax.min.js', array(), false, true );
		wp_enqueue_script( '-glowCookies', get_template_directory_uri() . '/include/assets/js/glowCookies.min.js', array(), false, false );
		if(function_exists('vc_map')) {
			wp_enqueue_script( 'prettyphoto', true, array(), false, true );
		}

		if(function_exists('vc_map')) {
			$prettyphoto_variable = "a[rel^='prettyPhoto']";
			wp_add_inline_script( "prettyphoto", 'jQuery(document).ready(function($){
				$(function () {
					$("' . $prettyphoto_variable . '").prettyPhoto({ social_tools: false });
				});
			});' );			
		}
		wp_enqueue_script( 'nucy', get_template_directory_uri() . '/include/assets/js/nucy.js', array(), false, true );

		wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/include/assets/css/bootstrap.min.css' );
		wp_enqueue_style( 'fontawesome', get_template_directory_uri() . '/include/assets/css/fontawesome-all.min.css' );
		wp_enqueue_style( 'jscrollpane', get_template_directory_uri() . '/include/assets/css/jscrollpane.min.css' );
		wp_enqueue_style( 'swiper', get_template_directory_uri() . '/include/assets/css/swiper.min.css' );
		if( function_exists( 'vc_map' ) ) {
			wp_enqueue_style( 'prettyphoto' );
		}
		wp_enqueue_style( 'nucy', get_stylesheet_uri() );
	}
	add_action( 'wp_enqueue_scripts', 'nucy_scripts' );



	/*======
	*
	* Admin Scripts & Styles
	*
	======*/
	function nucy_admin_scripts() {
		wp_enqueue_style( 'nucy-admin-metabox', get_template_directory_uri() . '/include/customize/assets/css/metabox.css', false, '1.0' );
		wp_enqueue_script( 'nucy-admin-metabox', get_template_directory_uri() . '/include/customize/assets/js/metabox.js', false, '1.0' );

		if ( is_customize_preview() ) {
			wp_enqueue_style( 'nucy-admin-customize', get_template_directory_uri() . '/include/customize/assets/css/customize.css', false, '1.0' );
			wp_enqueue_script( 'nucy-admin-customize', get_template_directory_uri() . '/include/customize/assets/js/customize.js', false, '1.0' );
		}
	}
	add_action( 'admin_enqueue_scripts', 'nucy_admin_scripts' );



	/*======
	*
	* Demo Importer
	*
	======*/
	function nucy_demo_content() {
		return array(
			array(
				'import_file_name' => esc_html__( 'Import Demo Content', 'nucy' ),
				'import_file_url' => get_template_directory_uri() . '/include/demos/demo-content.xml',
				'import_widget_file_url' => get_template_directory_uri() . '/include/demos/widget-content.wie',
			),
		);
	}
	add_filter( 'pt-ocdi/import_files', 'nucy_demo_content' );



	/*======
	*
	* Body Classes
	*
	======*/
	function nucy_class_names( $classes ) {
		$classes[] = 'nucy-theme';
		return $classes;
	}
	add_filter( 'body_class', 'nucy_class_names' );



	/*======
	*
	* Excerpt More
	*
	======*/
	function nucy_excerpt_more( $more ) {
		return '...';
	}
	add_filter( 'excerpt_more', 'nucy_excerpt_more' );



	/*======
	*
	* Excerpt Support for Pages
	*
	======*/
	function nucy_excerpts_for_pages() {
		add_post_type_support( 'page', 'excerpt' );
	}
	add_action( 'init', 'nucy_excerpts_for_pages' );



	/*======
	*
	* Word Cutter
	*
	======*/
	function nucy_word_cutter( $string = "", $word_limit = "" ) {
		$words = explode( ' ', $string, ( $word_limit + 1 ) );
		if( count( $words ) > $word_limit ) {
			array_pop( $words );
		}
		return implode( ' ', $words );
	}



	/*======
	*
	* Global Date Converter
	*
	======*/
	function nucy_global_date_converter( $date = "" ) {
		$date = date_i18n( get_option( 'date_format' ), strtotime( $date ) );
		return $date;
	}



	/*======
	*
	* Finding Slug
	*
	======*/
	function nucy_to_slug( $string ) {
		return strtolower( trim( preg_replace('/[^A-Za-z0-9-]+/', '-', $string ) ) );
	}



	/*======
	*
	* Menus
	*
	======*/
	register_nav_menus( 
		array(
			'main-menu' => esc_html__( 'Main Menu', 'nucy' ),
			'footer-menu' => esc_html__( 'Footer Menu', 'nucy' ),
			'copyright-menu' => esc_html__( 'Copyright Menu', 'nucy' ),
		)
	);



	/*======
	*
	* Menu Walker
	*
	======*/
	class nucy_walker extends Walker_Nav_Menu {
		public function start_lvl( &$output, $depth = 0, $args = array() ) {
			$indent = str_repeat( "\t", $depth );
			$output .= "\n$indent<ul role=\"menu\">\n";
		}

		function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {

			$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';

			$li_attributes = '';
			$class_names = $value = '';

			$classes = empty( $item->classes ) ? array() : (array) $item->classes;

			if ($args->has_children){
				$classes[] 		= 'dropdown';
				$li_attributes .= ' data-dropdown="dropdown"';
			}
			$classes[] = 'menu-item-' . $item->ID;
			$classes[] = ($item->current) ? 'active' : '';

			$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item, $args ) );
			$class_names = ' class="nav-item ' . esc_attr( $class_names ) . '"';

			$id = apply_filters( 'nav_menu_item_id', 'menu-item-'. $item->ID, $item, $args );
			$id = strlen( $id ) ? ' id="' . esc_attr( $id ) . '"' : '';

			$output .= $indent . '<li' . $id . $value . $class_names . $li_attributes . '>';

			$attributes  = ! empty( $item->attr_title ) ? ' title="'  . esc_attr( $item->attr_title ) .'"' : '';
			$attributes .= ! empty( $item->target ) ? ' target="' . esc_attr( $item->target ) .'"' : '';
			$attributes .= ! empty( $item->xfn ) ? ' rel="'    . esc_attr( $item->xfn ) .'"' : '';
			$attributes .= ! empty( $item->url ) ? ' href="'   . esc_attr( $item->url ) .'"' : '';
			$attributes .= ! empty( $item->url ) ? ' class="nav-link"' : '';
			$attributes .= ($args->has_children) ? ' ' : ''; 

			$item_output = $args->before;
			$item_output .= '<a'. $attributes .'>';
				$item_output .= $args->link_before;
				$item_output .= apply_filters( 'the_title', $item->title, $item->ID );
				$item_output .= $args->link_after;
			$item_output .= ($args->has_children) ? '' : '';
			$item_output .= '</a>';
			$item_output .= $args->after;

			$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
		}

		public function display_element( $element, &$children_elements, $max_depth, $depth, $args, &$output ) {
	        if ( ! $element )
	            return;
	        $id_field = $this->db_fields['id'];
	        // Display this element.
	        if ( is_object( $args[0] ) )
	           $args[0]->has_children = ! empty( $children_elements[ $element->$id_field ] );
	        parent::display_element( $element, $children_elements, $max_depth, $depth, $args, $output );
	    }
	}



	/*======
	*
	* Search Form
	*
	======*/
	function nucy_search_form() {
		$output = '<form role="search" method="get" class="searchform" action="' . esc_url( home_url( '/' ) ) . '">
			<div class="search-form">
				<input type="text" value="' . esc_attr( get_search_query() ) . '" placeholder="' . esc_attr__( 'Enter the keyword...', 'nucy' ) . '" name="s" class="searchform-text" />
				<button><i class="fas fa-search" aria-hidden="true"></i></button>
			</div>
		</form>';

		return $output;
	}



	/*======
	*
	* Social Media Sites
	*
	======*/
	function nucy_social_media_sites() {
		$social_sites = nucy_social_media_array_filter();

		foreach ( $social_sites as $social_site => $profile ) {
			if ( strlen( get_theme_mod( $social_site ) ) > 0 ) {
				$active_social_sites[ $social_site ] = $social_site;
			}
		}

		if ( ! empty( $active_social_sites ) ) {
			$output = '<ul class="gt-social-links">';
				foreach ( $active_social_sites as $key => $active_site ) {
					$icon_class = 'fa-' . esc_attr( $active_site );
					$link_name = $active_site;
					$label = ucfirst( $active_site );

					if ( $active_site == 'twitter' ) {
						$label = esc_html__( 'Twitter', 'nucy' );
					} elseif ( $active_site == 'facebook' ) {
						$label = esc_html__( 'Facebook', 'nucy' );
						$icon_class = 'fa-facebook-f';
					} elseif ( $active_site == 'google-plus' ) {
						$label = esc_html__( 'Google Plus', 'nucy' );
						$icon_class = 'fa-google-plus-g';
					} elseif ( $active_site == 'pinterest' ) {
						$label = esc_html__( 'Pinterest', 'nucy' );
						$icon_class = 'fa-pinterest-p';
					} elseif ( $active_site == 'youtube' ) {
						$label = esc_html__( 'YouTube', 'nucy' );
					} elseif ( $active_site == 'vimeo' ) {
						$label = esc_html__( 'Vimeo', 'nucy' );
						$icon_class = 'fa-vimeo-v';
					} elseif ( $active_site == 'tumblr' ) {
						$label = esc_html__( 'Tumblr', 'nucy' );
					} elseif ( $active_site == 'instagram' ) {
						$label = esc_html__( 'Instagram', 'nucy' );
					} elseif ( $active_site == 'flickr' ) {
						$label = esc_html__( 'Flickr', 'nucy' );
					} elseif ( $active_site == 'dribbble' ) {
						$label = esc_html__( 'Dribbble', 'nucy' );
					} elseif ( $active_site == 'reddit' ) {
						$label = esc_html__( 'Reddit', 'nucy' );
						$icon_class = 'fa-reddit-alien';
					} elseif ( $active_site == 'soundcloud' ) {
						$label = esc_html__( 'SoundCloud', 'nucy' );
					} elseif ( $active_site == 'spotify' ) {
						$label = esc_html__( 'Spotify', 'nucy' );
					} elseif ( $active_site == 'yahoo' ) {
						$label = esc_html__( 'Yahoo', 'nucy' );
					} elseif ( $active_site == 'behance' ) {
						$label = esc_html__( 'Behance', 'nucy' );
					} elseif ( $active_site == 'delicious' ) {
						$label = esc_html__( 'Delicious', 'nucy' );
					} elseif ( $active_site == 'stumbleupon' ) {
						$label = esc_html__( 'Stumbleupon', 'nucy' );
					} elseif ( $active_site == 'deviantart' ) {
						$label = esc_html__( 'DeviantArt', 'nucy' );
					} elseif ( $active_site == 'digg' ) {
						$label = esc_html__( 'Digg', 'nucy' );
					} elseif ( $active_site == 'github' ) {
						$label = esc_html__( 'GitHub', 'nucy' );
					} elseif ( $active_site == 'medium' ) {
						$label = esc_html__( 'Medium', 'nucy' );
						$icon_class = 'fa-medium-m';
					} elseif ( $active_site == 'steam' ) {
						$label = esc_html__( 'Steam', 'nucy' );
						$icon_class = 'fa-steam-symbol';
					} elseif ( $active_site == 'vk' ) {
						$label = esc_html__( 'VK', 'nucy' );
					} elseif ( $active_site == '500px' ) {
						$label = esc_html__( '500px', 'nucy' );
					} elseif ( $active_site == 'foursquare' ) {
						$label = esc_html__( 'Foursquare', 'nucy' );
					} elseif ( $active_site == 'slack' ) {
						$label = esc_html__( 'Slack', 'nucy' );
						$icon_class = 'fa-slack-hash';
					} elseif ( $active_site == 'whatsapp' ) {
						$label = esc_html__( 'WhatsApp', 'nucy' );
					} elseif ( $active_site == 'twitch' ) {
						$label = esc_html__( 'Twitch', 'nucy' );
					} elseif ( $active_site == 'paypal' ) {
						$label = esc_html__( 'PayPal', 'nucy' );
					} elseif ( $active_site == 'rss' ) {
						$label = esc_html__( 'RSS', 'nucy' );
						$icon_class = 'fas fa-rss';
					} elseif ( $active_site == 'codepen' ) {
						$label = esc_html__( 'CodePen', 'nucy' );
					} elseif ( $active_site == 'linkedin' ) {
						$label = esc_html__( 'LinkedIn', 'nucy' );
						$icon_class = 'fa-linkedin-in';
					} elseif ( $active_site == 'custom-url' ) {
						$label = esc_html__( 'Custom Link', 'nucy' );
						$icon_class = 'fas fa-external-link-alt';
					}

					$output .='<li>';
						$target_name = $link_name . '-target';
						if( !empty( $target_name ) ) {
							if( !empty( get_theme_mod( $target_name ) ) or get_theme_mod( $target_name ) == "1" ) {
								$target = '_blank';
							} else {
								$target = '_self';
							}
						}
						$output .= '<a href="' . esc_url( get_theme_mod( $key ) ) . '" class="' . esc_attr( $link_name ) . '" title="' . esc_attr( $label ) . '" target="' . esc_attr( $target ) . '">';
							$output .= '<i class="fab ' . esc_attr( $icon_class ) . '"></i>';
						$output .= '</a>';
					$output .= '</li>';
				}
			$output .= '</ul>';

			return $output;
		}
	}


/*======
*
* Comment List Template
*
======*/
	function nucy_comment( $comment, $args, $depth ) {
		$GLOBALS['comment'] = $comment;
		extract($args, EXTR_SKIP);

		if ( 'div' == $args['style'] ) {
			$tag = 'div';
			$add_below = 'comment';
		} else {
			$tag = 'li';
			$add_below = 'div-comment';
		}
		?>
			<<?php echo esc_attr( $tag ) ?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ) ?> id="comment-<?php comment_ID() ?>">
			
			<?php if ( 'div' != $args['style'] ) { ?>
				<div id="div-comment-<?php comment_ID() ?>" class="comment-wrapper">
			<?php } ?>
				<div class="comment-image">
					<?php $user = get_user_by( 'email', $comment->comment_author_email ); ?>
					<?php if ( $args['avatar_size'] != 0 ) { echo get_avatar( $comment, $args['avatar_size'] ); } ?>
				</div>

				<div class="comment-content">
					<div class="comment-author">
						<?php
							$author_control = get_comment_author();
							if( !empty( $author_control ) ) {
								echo get_comment_author(); 
							}
						?>
					</div>

					<?php if ( $comment->comment_approved == '0' ) { ?>
						<p class="moderation-message"><?php esc_html_e( 'Your comment is awaiting moderation.', 'nucy' ); ?></p>
					<?php } ?>

					<?php comment_text(); ?>

					<div class="comment-info">
						<div class="item comment-meta commentmetadata">
							<i class="far fa-clock" aria-hidden="true"></i>
							<a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ); ?>">
								<?php printf( esc_html__( '%1$s', 'nucy' ), get_comment_date(),  get_comment_time() ); ?>
							</a>
						</div>
						
						<?php comment_reply_link( array_merge( $args, array( 'add_below' => $add_below, 'depth' => $depth, 'max_depth' => $args['max_depth'], 'before' => '<div class="item reply"><i class="fas fa-reply" aria-hidden="true"></i>', 'after' => '</div>' ) ) ); ?>
						
						<?php edit_comment_link( esc_html__( 'Edit', 'nucy' ), '<div class="item edit"><i class="fas fa-pencil-alt" aria-hidden="true"></i>', '</div>' ); ?>
					</div>
				</div>

			<?php if ( 'div' != $args['style'] ) { ?>
				</div>
			<?php }
	}



	/*======
	*
	* WooCommerce Support
	*
	======*/
	if( class_exists( 'Woocommerce' ) ) {
		function nucy_woocommerce_support() {
			add_theme_support( 'woocommerce' );
		}
		add_action( 'after_setup_theme', 'nucy_woocommerce_support' );
	}



	/*======
	*
	* Sidebars
	*
	======*/
	if( !function_exists( 'nucy_sidebars_init' ) ) {
		function nucy_sidebars_init() {
			register_sidebar(
				array(
					'id' => 'nucy-sidebar',
					'name' => esc_html__( 'General Sidebar', 'nucy' ),
					'before_widget' => '<div id="%1$s" class="gt-widget %2$s">',
					'after_widget' => '</div>',
					'before_title' => '<div class="gt-widget--heading"><div class="gt-widget--title">',
					'after_title' => '</div></div>',
				)
			);

			register_sidebar(
				array(
					'id' => 'nucy-shop-sidebar',
					'name' => esc_html__( 'Shop Sidebar', 'nucy' ),
					'before_widget' => '<div id="%1$s" class="gt-widget %2$s">',
					'after_widget' => '</div>',
					'before_title' => '<div class="gt-widget--heading"><div class="gt-widget--title">',
					'after_title' => '</div></div>',
				)
			);

			register_sidebar(
				array(
					'id' => 'nucy-header-sidebar',
					'name' => esc_html__( 'Header Sidebar', 'nucy' ),
					'before_widget' => '<div id="%1$s" class="gt-widget %2$s">',
					'after_widget' => '</div>',
					'before_title' => '<div class="gt-widget--heading"><div class="gt-widget--title">',
					'after_title' => '</div></div>',
				)
			);
		}
	}
	add_action( 'widgets_init', 'nucy_sidebars_init' );


	/*======
	*
	* Sidebar & Wrapper Layouts
	*
	======*/
	function nucy_content_before() {
		if( is_category() ) {
			$sidebar_position = get_theme_mod( 'nucy_archives_categories_sidebar_position', 'right-sidebar' );
		} elseif( is_search() ) {
			$sidebar_position = get_theme_mod( 'nucy_archives_searches_sidebar_position', 'right-sidebar' );
		} elseif ( is_post_type_archive( 'portfolio' ) or is_tax( 'portfolio' ) or get_post_type( get_the_ID() ) == 'portfolio' ) {
			$sidebar_position = get_theme_mod( 'nucy_portfolio_sidebar_position', 'no-sidebar' );
		} elseif( is_tag() ) {
			$sidebar_position = get_theme_mod( 'nucy_archives_tags_sidebar_position', 'right-sidebar' );
		} elseif( is_author() ) {
			$sidebar_position = get_theme_mod( 'nucy_archives_authors_sidebar_position', 'right-sidebar' );
		} elseif( is_archive() ) {
			$sidebar_position = get_theme_mod( 'nucy_archives_archives_sidebar_position', 'right-sidebar' );
		} elseif( is_attachment() ) {
			$sidebar_position = get_theme_mod( 'nucy_archives_attachments_sidebar_position', 'no-sidebar' );
		} elseif( is_single() ) {
			$sidebar_position = get_theme_mod( 'nucy_posts_sidebar_position', 'right-sidebar' );
		} elseif( is_page() ) {
			$sidebar_position = get_theme_mod( 'nucy_pages_sidebar_position', 'no-sidebar' );
		} else {
			$sidebar_position = get_theme_mod( 'nucy_general_sidebar_position', 'right-sidebar' );
		}

		if( is_single() or is_page() ) {
			$custom_sidebar_position = get_post_meta( get_the_ID(), 'sidebar-position', true );
			if( !empty( $custom_sidebar_position ) ) {
				$sidebar_position = $custom_sidebar_position;
			}
		}

		if( $sidebar_position == 'no-sidebar' ) {
			echo '<div class="col-lg-12 col-md-12 col-sm-12 col-xs-12 left-layout">';
		}
		
		elseif( $sidebar_position == 'left-sidebar' ) {
			echo '<div class="col-lg-8 col-md-8 col-sm-12 col-xs-12 left-layout sidebar-align-right">';
		}
		
		elseif( $sidebar_position == 'right-sidebar' ) {
			echo '<div class="col-lg-8 col-md-8 col-sm-12 col-xs-12 left-layout">';
		}
		
		else {
			echo '<div class="col-lg-8 col-md-8 col-sm-12 col-xs-12 left-layout">';
		}
	}

	function nucy_content_after() {
		echo '</div>';
	}

	function nucy_sidebar_before() {
		if( is_category() ) {
			$sidebar_position = get_theme_mod( 'nucy_archives_categories_sidebar_position', 'right-sidebar' );
		} elseif( is_search() ) {
			$sidebar_position = get_theme_mod( 'nucy_archives_searches_sidebar_position', 'right-sidebar' );
		} elseif ( is_post_type_archive( 'portfolio' ) or is_tax( 'portfolio' ) or get_post_type( get_the_ID() ) == 'portfolio' ) {
			$sidebar_position = get_theme_mod( 'nucy_portfolio_sidebar_position', 'no-sidebar' );
		} elseif( is_tag() ) {
			$sidebar_position = get_theme_mod( 'nucy_archives_tags_sidebar_position', 'right-sidebar' );
		} elseif( is_author() ) {
			$sidebar_position = get_theme_mod( 'nucy_archives_authors_sidebar_position', 'right-sidebar' );
		} elseif( is_archive() ) {
			$sidebar_position = get_theme_mod( 'nucy_archives_archives_sidebar_position', 'right-sidebar' );
		} elseif( is_attachment() ) {
			$sidebar_position = get_theme_mod( 'nucy_archives_attachments_sidebar_position', 'no-sidebar' );
		} elseif( is_single() ) {
			$sidebar_position = get_theme_mod( 'nucy_posts_sidebar_position', 'right-sidebar' );
		} elseif( is_page() ) {
			$sidebar_position = get_theme_mod( 'nucy_pages_sidebar_position', 'no-sidebar' );
		} else {
			$sidebar_position = get_theme_mod( 'nucy_general_sidebar_position', 'right-sidebar' );
		}

		if( is_single() or is_page() ) {
			$custom_sidebar_position = get_post_meta( get_the_ID(), 'sidebar-position', true );
			if( !empty( $custom_sidebar_position ) ) {
				$sidebar_position = $custom_sidebar_position;
			}
		}
		
		if( $sidebar_position == 'no-sidebar' ) {
			echo '<div class="col-lg-12 col-md-12 col-sm-12 col-xs-12 d-none">';
		}
		
		elseif( $sidebar_position == 'left-sidebar' ) {
			echo '<div class="col-lg-4 col-md-4 col-sm-12 col-xs-12 right-layout sidebar-align-left fixed-sidebar">';
		}
		
		elseif( $sidebar_position == 'right-sidebar' ) {
			echo '<div class="col-lg-4 col-md-4 col-sm-12 col-xs-12 right-layout fixed-sidebar">';
		}
		
		else {
			echo '<div class="col-lg-4 col-md-4 col-sm-12 col-xs-12 right-layout fixed-sidebar">';
		}
	}

	function nucy_sidebar_after() {
		echo '</div>';
	}



	/*======
	*
	* Theme Wrapper
	*
	======*/
	function nucy_wrapper_before() {
		echo '<main class="gt-main">';
	}

	function nucy_wrapper_after() {
		echo '</main>';
	}



	/*======
	*
	* Row Wrapper
	*
	======*/
	function nucy_row_before( $extra_class = "", $echo = "true" ) {
		if( !empty( $extra_class ) ) {
			$extra_class = ' ' . $extra_class;
		}

		if( $echo == "true" ) {
			echo '<div class="row' . $extra_class . '">';
		} else {
			$output = '<div class="row' . $extra_class . '">';
			return $output;
		}
	}

	function nucy_row_after( $echo = "true" ) {
		if( $echo == "true" ) {
			echo '</div>';
		} else {
			$output = '</div>';
			return $output;
		}
	}



	/*======
	*
	* Container Wrapper
	*
	======*/
	function nucy_container_before( $extra_class = "", $echo = "true" ) {
		if( !empty( $extra_class ) ) {
			$extra_class = ' ' . $extra_class;
		}

		if( $echo == "true" ) {
			echo '<div class="container' . $extra_class . '">';
		} else {
			$output = '<div class="container' . $extra_class . '">';
			return $output;
		}
	}

	function nucy_container_after( $echo = "true" ) {
		if( $echo == "true" ) {
			echo '</div>';
		} else {
			$output = '</div>';
			return $output;
		}
	}



	/*======
	*
	* Fluid Container Wrapper
	*
	======*/
	function nucy_fluid_container_before( $extra_class = "" ) {
		if( !empty( $extra_class ) ) {
			$extra_class = ' ' . $extra_class;
		}
		echo '<div class="fluid-container' . $extra_class . '">';
	}

	function nucy_fluid_container_after() {
		echo '</div>';
	}



	/*======
	*
	* Site Logo
	*
	======*/
	function nucy_header_site_logo() {
		$output = "";

		$logo = get_theme_mod( 'nucy_header_logo' );

		$logo_height = get_theme_mod( 'nucy_header_logo_height' );
		if( !empty( $logo_height ) ) {
			$logo_height = 'height="' . esc_attr( $logo_height ) . '"';
		}

		$logo_width = get_theme_mod( 'nucy_header_logo_width' );
		if( !empty( $logo_width ) ) {
			$logo_width = 'width="' . esc_attr( $logo_width ) . '"';
		}

		if( !$logo == ""  ) {
			$output .= '<a href="' . esc_url( home_url( '/' ) ) . '" title="' . esc_attr( get_bloginfo( 'name' ) ) . '">';
				$output .= '<img alt="' . esc_attr( get_bloginfo( 'name' ) ) . '" src="' . esc_url( wp_get_attachment_url( $logo ) ) . '" ' . $logo_height . $logo_width . ' />';
			$output .= '</a>';
		} else {
			$output .= '<a href="' . esc_url( home_url( '/' ) ) . '" title="' . esc_attr( get_bloginfo( 'name' ) ) . '">';
				$output .= '<span>' . esc_attr( get_bloginfo( 'name' ) ) . '</span>';
			$output .= '</a>';
		}

		return $output;
	}




	/*======
	*
	* Header Elements
	*
	======*/
	function nucy_header_elements( $search = "true", $social = "true", $language = "true", $menu = "true" ) {
		$output = "";

		$header_language_selector = get_theme_mod( 'nucy_header_language_selector' );
		$header_search = get_theme_mod( 'nucy_header_search', '1' );
		$header_social_media = get_theme_mod( 'nucy_header_social_media', '1' );
		$header_sidebar = get_theme_mod( 'nucy_header_sidebar', '1' );

		if( $search == "true" or $social == "true" or $language == "true"  or $menu == "true" ) {
			$output .= '<div class="gt-icons d-flex align-items-center justify-content-end">';
				if( $header_language_selector == "1" ) {
					if( $language == "true" ) {
						$output .= '<div class="gt-icon gt-icon--language" data-language="EN">';
							$output .= '<svg viewBox="0 0 22 22" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <path d="M11,22 C4.92486775,22 0,17.0751322 0,11 C0,4.92486775 4.92486775,0 11,0 C17.0751322,0 22,4.92486775 22,11 C22,17.0751322 17.0751322,22 11,22 Z M11,20 C15.9705627,20 20,15.9705627 20,11 C20,6.02943725 15.9705627,2 11,2 C6.02943725,2 2,6.02943725 2,11 C2,15.9705627 6.02943725,20 11,20 Z M7.99978307,10.9791717 C8.06399619,14.0614835 9.12203221,17.0297279 11.0000219,19.4492318 C12.8779842,17.0301914 13.9360043,14.0660671 14.0002169,11.0208283 C13.9360038,7.93851654 12.8779678,4.97027215 10.9999781,2.5507682 C9.12201578,4.96980861 8.06399569,7.9339329 7.99978307,10.9791717 Z M11.7383452,0.325576969 C14.4031079,3.24290718 15.917487,7.02885486 15.9997831,11.0208283 C15.917487,14.9711451 14.4031079,18.7570928 11.7383452,21.674423 C11.3418249,22.1085257 10.6581751,22.1085257 10.2616548,21.674423 C7.59689209,18.7570928 6.08251301,14.9711451 6.00021693,10.9791717 C6.08251301,7.02885486 7.59689209,3.24290718 10.2616548,0.325576969 C10.6581751,-0.108525656 11.3418249,-0.108525656 11.7383452,0.325576969 Z M1,12 C0.44771525,12 0,11.5522847 0,11 C0,10.4477153 0.44771525,10 1,10 L21,10 C21.5522847,10 22,10.4477153 22,11 C22,11.5522847 21.5522847,12 21,12 L1,12 Z" fill-rule="nonzero"></path> </g> </svg>
						</div>';
					}
				}

				if( $header_search == "1" ) {
					if( $search == "true" ) {
						$output .= '<div class="gt-icon gt-icon--search">';
							$output .= '<svg viewBox="0 0 20 20" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <path d="M19.7071068,18.2928932 C20.0976311,18.6834175 20.0976311,19.3165825 19.7071068,19.7071068 C19.3165825,20.0976311 18.6834175,20.0976311 18.2928932,19.7071068 L13.9428932,15.3571068 C13.5523689,14.9665825 13.5523689,14.3334175 13.9428932,13.9428932 C14.3334175,13.5523689 14.9665825,13.5523689 15.3571068,13.9428932 L19.7071068,18.2928932 Z M9,18 C4.02943725,18 0,13.9705627 0,9 C0,4.02943725 4.02943725,0 9,0 C13.9705627,0 18,4.02943725 18,9 C18,13.9705627 13.9705627,18 9,18 Z M9,16 C12.8659932,16 16,12.8659932 16,9 C16,5.13400675 12.8659932,2 9,2 C5.13400675,2 2,5.13400675 2,9 C2,12.8659932 5.13400675,16 9,16 Z" fill-rule="nonzero"></path> </g> </svg>';
						$output .= '</div>';
					}
				}

				if( $header_social_media == "1" ) {
					if( $social == "true" ) {
						if( !empty( nucy_social_media_sites() ) ) {
							$output .= '<div class="gt-icon gt-icon--share">';
								$output .= '<svg viewBox="0 0 20 22" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <path d="M16,22 C13.790861,22 12,20.209139 12,18 C12,15.790861 13.790861,14 16,14 C18.209139,14 20,15.790861 20,18 C20,20.209139 18.209139,22 16,22 Z M16,20 C17.1045695,20 18,19.1045695 18,18 C18,16.8954305 17.1045695,16 16,16 C14.8954305,16 14,16.8954305 14,18 C14,19.1045695 14.8954305,20 16,20 Z M4,15 C1.790861,15 0,13.209139 0,11 C0,8.790861 1.790861,7 4,7 C6.209139,7 8,8.790861 8,11 C8,13.209139 6.209139,15 4,15 Z M4,13 C5.1045695,13 6,12.1045695 6,11 C6,9.8954305 5.1045695,9 4,9 C2.8954305,9 2,9.8954305 2,11 C2,12.1045695 2.8954305,13 4,13 Z M13.1580623,6.81485207 L7.0940285,10.353687 C6.61702733,10.6320543 6.00468023,10.4710297 5.72631298,9.9940285 C5.44794572,9.51702733 5.60897033,8.90468023 6.0859715,8.62631298 L12.1496575,5.08768096 C12.0521601,4.7418517 12,4.37701717 12,4 C12,1.790861 13.790861,0 16,0 C18.209139,0 20,1.790861 20,4 C20,6.209139 18.209139,8 16,8 C14.8885419,8 13.8829617,7.54668304 13.1580623,6.81485207 Z M14.3003036,5.05457301 C14.653203,5.62215038 15.2824757,6 16,6 C17.1045695,6 18,5.1045695 18,4 C18,2.8954305 17.1045695,2 16,2 C14.8954305,2 14,2.8954305 14,4 C14,4.34730478 14.0885253,4.67393338 14.2442424,4.9585523 C14.2544289,4.97399233 14.2642499,4.98980034 14.273687,5.0059715 C14.2830553,5.02202467 14.2919259,5.03823114 14.3003036,5.05457301 Z M6.0865223,13.3740082 C5.60934373,13.0959452 5.44792872,12.4837009 5.72599178,12.0065223 C6.00405484,11.5293437 6.61629914,11.3679287 7.0934777,11.6459918 L13.9234777,15.6259918 C14.4006563,15.9040548 14.5620713,16.5162991 14.2840082,16.9934777 C14.0059452,17.4706563 13.3937009,17.6320713 12.9165223,17.3540082 L6.0865223,13.3740082 Z" fill-rule="nonzero"></path> </g> </svg>';
							$output .= '</div>';
						}
					}
				}

				if( $header_sidebar == "1" ) {
					if( $menu == "true" ) {
						if ( is_active_sidebar( 'nucy-header-sidebar' ) ) {
							$output .= '<div class="gt-icon gt-icon--side-panel-open">';
								$output .= '<svg viewBox="0 0 18 4" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g fill-rule="evenodd"><path d="M16,4 C14.8954305,4 14,3.1045695 14,2 C14,0.8954305 14.8954305,0 16,0 C17.1045695,0 18,0.8954305 18,2 C18,3.1045695 17.1045695,4 16,4 Z M9,4 C7.8954305,4 7,3.1045695 7,2 C7,0.8954305 7.8954305,0 9,0 C10.1045695,0 11,0.8954305 11,2 C11,3.1045695 10.1045695,4 9,4 Z M2,4 C0.8954305,4 0,3.1045695 0,2 C0,0.8954305 0.8954305,0 2,0 C3.1045695,0 4,0.8954305 4,2 C4,3.1045695 3.1045695,4 2,4 Z"></path></g></svg>';
							$output .= '</div>';
						}
					}
				}
			$output .= '</div>';
		}

		return $output;
	}



	/*======
	*
	* Header
	*
	======*/
	function nucy_header() {
		$header_status = get_theme_mod( 'nucy_header_status', '1' );
		$header_status_default = get_theme_mod( 'nucy_header_status', '1' );
		$header_style = get_theme_mod( 'nucy_header_general_style', 'style-1' );
		$header_style_default = get_theme_mod( 'nucy_header_general_style', 'style-1' );

		if ( !$header_status_default == '' or $header_status_default == '1' ) {
			/*====== Post & Page Header Selector ======*/
			if ( is_page() or is_single() ) {
				global $post;
				$header_style = get_post_meta( $post->ID, 'header-style', true );
				if( empty( $header_style ) ) {
					$header_style = $header_style_default;
				}
			} else {
				$header_style = $header_style_default;
			}



			/*====== Header Styles ======*/
				/*====== Style 1 ======*/
				function nucy_navbar_style_1() {
					$output = '<nav class="gt-navbar d-flex align-items-center justify-content-start">';
						$output .= wp_nav_menu(
							array(
								'theme_location' => 'main-menu',
								'depth' => 5,
								'container' => 'ul',
								'fallback_cb' => 'nucy_walker::fallback',
								'walker' => new nucy_walker(),
								'echo' => false
							)
						);
					$output .= '</nav>';

					return $output;
				}



			/*====== Header Styles ======*/
				/*====== Style 1 ======*/
				function nucy_header_style_1() {
					$output = "";

					$header_language_selector = get_theme_mod( 'nucy_header_language_selector' );
					$header_search = get_theme_mod( 'nucy_header_search', '1' );
					$header_social_media = get_theme_mod( 'nucy_header_social_media', '1' );
					$header_phone_number = get_theme_mod( 'nucy_header_phone_number' );
					$header_working_hours = get_theme_mod( 'nucy_header_working_hours' );
					$header_email_address = get_theme_mod( 'nucy_header_email_address' );
					$header_search = get_theme_mod( 'nucy_header_search', '1' );
					$header_home_icon = get_theme_mod( 'nucy_header_home_icon', '1' );
					$header_sidebar = get_theme_mod( 'nucy_header_sidebar', '1' );
					$header_information = get_theme_mod( 'nucy_header_information', '1' );

					$output .= '<header class="gt-header">';
						$output .= '<div class="container">';
							$output .= '<div class="gt-header--inner">';
								$output .= '<div class="gt-header--top d-flex align-items-center">';
									$output .= '<div class="container d-flex align-items-center justify-content-between">';
										$output .= '<div class="gt-logo">';
											$output .= nucy_header_site_logo();
										$output .= '</div>';

										if( $header_information == "1" ) {
											if( !empty( $header_phone_number ) or !empty( $header_working_hours ) or !empty( $header_email_address ) ) {
												$output .= '<div class="gt-information">';
													if( !empty( $header_phone_number ) ) {
														$output .= '<div class="gt-box">';
															$output .= '<div class="gt-box--icon"><i class="fas fa-phone"></i></div>';
															$output .= '<div class="gt-box--content">' . esc_attr( get_theme_mod( 'nucy_header_phone_number' ) ) . '</div>';
														$output .= '</div>';
													}

													if( !empty( $header_working_hours ) ) {
														$output .= '<div class="gt-box">';
															$output .= '<div class="gt-box--icon"><i class="far fa-clock"></i></div>';
															$output .= '<div class="gt-box--content">' . esc_attr( get_theme_mod( 'nucy_header_working_hours' ) ) . '</div>';
														$output .= '</div>';
													}

													if( !empty( $header_email_address ) ) {
														$output .= '<div class="gt-box">';
															$output .= '<div class="gt-box--icon"><i class="fas fa-at"></i></div>';
															$output .= '<div class="gt-box--content">' . esc_attr( get_theme_mod( 'nucy_header_email_address' ) ) . '</div>';
														$output .= '</div>';
													}
												$output .= '</div>';
											}
										}

										$output .= nucy_header_elements( $search = "true", $social = "true", $language = "true", $menu = "false" );
									$output .= '</div>';
								$output .= '</div>';

								$output .= '<div class="gt-header--bottom d-flex align-items-center">';
									$output .= '<div class="container d-flex align-items-center justify-content-between">';
										if( $header_home_icon == "1" ) {
											$output .= '<div class="gt-icons">';
												$output .= '<div class="gt-icon">';
													$output .= '<a href="' . esc_url( home_url( '/' ) ) . '" class="site-logo" title="' . esc_attr__( 'Home', 'nucy' ) . '">';
														$output .= '<svg viewBox="0 0 20 22" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <path d="M2,8.48908381 L2,19 C2,19.5522847 2.44771525,20 3,20 L17,20 C17.5522847,20 18,19.5522847 18,19 L18,8.48908381 L10,2.26686158 L2,8.48908381 Z M0.386059386,7.21064778 L9.38605939,0.210647783 C9.74716987,-0.0702159275 10.2528301,-0.0702159275 10.6139406,0.210647783 L19.6139406,7.21064778 C19.8575272,7.40010398 20,7.69140957 20,8 L20,19 C20,20.6568542 18.6568542,22 17,22 L3,22 C1.34314575,22 0,20.6568542 0,19 L0,8 C0,7.69140957 0.142472844,7.40010398 0.386059386,7.21064778 Z M8,12 L8,21 C8,21.5522847 7.55228475,22 7,22 C6.44771525,22 6,21.5522847 6,21 L6,11 C6,10.4477153 6.44771525,10 7,10 L13,10 C13.5522847,10 14,10.4477153 14,11 L14,21 C14,21.5522847 13.5522847,22 13,22 C12.4477153,22 12,21.5522847 12,21 L12,12 L8,12 Z" fill-rule="nonzero"></path> </g> </svg>';
													$output .= '</a>';
												$output .= '</div>';
											$output .= '</div>';
										}

										$output .= nucy_navbar_style_1();

										if( $header_sidebar == "1" ) {
											if ( is_active_sidebar( 'nucy-header-sidebar' ) ) {
												$output .= '<div class="gt-icons">';
													$output .= '<div class="gt-icon gt-icon--side-panel-open">';
														$output .= '<svg viewBox="0 0 18 4" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g fill-rule="evenodd"><path d="M16,4 C14.8954305,4 14,3.1045695 14,2 C14,0.8954305 14.8954305,0 16,0 C17.1045695,0 18,0.8954305 18,2 C18,3.1045695 17.1045695,4 16,4 Z M9,4 C7.8954305,4 7,3.1045695 7,2 C7,0.8954305 7.8954305,0 9,0 C10.1045695,0 11,0.8954305 11,2 C11,3.1045695 10.1045695,4 9,4 Z M2,4 C0.8954305,4 0,3.1045695 0,2 C0,0.8954305 0.8954305,0 2,0 C3.1045695,0 4,0.8954305 4,2 C4,3.1045695 3.1045695,4 2,4 Z"></path></g></svg>';
													$output .= '</div>';
												$output .= '</div>';
											}
										}
									$output .= '</div>';
								$output .= '</div>';

								if( $header_search == "1" ) {
									$output .= '<div class="gt-header--panel gt-header--panel_search">';
										$output .= '<div class="gt-inner d-flex align-items-center">';
											$output .= '<div class="container d-flex align-items-center justify-content-between">';
												$output .= '<div class="gt-icons">';
													$output .= '<div class="gt-icon">';
														$output .= '<svg viewBox="0 0 20 20" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <path d="M19.7071068,18.2928932 C20.0976311,18.6834175 20.0976311,19.3165825 19.7071068,19.7071068 C19.3165825,20.0976311 18.6834175,20.0976311 18.2928932,19.7071068 L13.9428932,15.3571068 C13.5523689,14.9665825 13.5523689,14.3334175 13.9428932,13.9428932 C14.3334175,13.5523689 14.9665825,13.5523689 15.3571068,13.9428932 L19.7071068,18.2928932 Z M9,18 C4.02943725,18 0,13.9705627 0,9 C0,4.02943725 4.02943725,0 9,0 C13.9705627,0 18,4.02943725 18,9 C18,13.9705627 13.9705627,18 9,18 Z M9,16 C12.8659932,16 16,12.8659932 16,9 C16,5.13400675 12.8659932,2 9,2 C5.13400675,2 2,5.13400675 2,9 C2,12.8659932 5.13400675,16 9,16 Z" fill-rule="nonzero"></path> </g> </svg>';
													$output .= '</div>';
												$output .= '</div>';

												$output .= '<div class="gt-content d-flex align-items-center">';
													$output .= '<div class="gt-search--form">';
														$output .= '<form role="search" method="get" class="searchform" action="' . esc_url( home_url( '/' ) ) . '">';
															$output .= '<input type="text" value="' . esc_attr( get_search_query() ) . '" placeholder="' . esc_attr__( 'Enter the keyword...', 'nucy' ) . '" name="s" class="searchform-text" />';
														$output .= '</form>';
													$output .= '</div>';
												$output .= '</div>';

												$output .= '<div class="gt-icons">';
													$output .= '<div class="gt-icon gt-icon--close">';
														$output .= '<svg viewBox="0 0 14 14" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <path d="M8.41421356,7 L13.7071068,12.2928932 C14.0976311,12.6834175 14.0976311,13.3165825 13.7071068,13.7071068 C13.3165825,14.0976311 12.6834175,14.0976311 12.2928932,13.7071068 L7,8.41421356 L1.70710678,13.7071068 C1.31658249,14.0976311 0.683417511,14.0976311 0.292893219,13.7071068 C-0.0976310729,13.3165825 -0.0976310729,12.6834175 0.292893219,12.2928932 L5.58578644,7 L0.292893219,1.70710678 C-0.0976310729,1.31658249 -0.0976310729,0.683417511 0.292893219,0.292893219 C0.683417511,-0.0976310729 1.31658249,-0.0976310729 1.70710678,0.292893219 L7,5.58578644 L12.2928932,0.292893219 C12.6834175,-0.0976310729 13.3165825,-0.0976310729 13.7071068,0.292893219 C14.0976311,0.683417511 14.0976311,1.31658249 13.7071068,1.70710678 L8.41421356,7 Z"></path> </g> </svg>';
													$output .= '</div>';
												$output .= '</div>';
											$output .= '</div>';
										$output .= '</div>';
									$output .= '</div>';
								}

								if( $header_language_selector == "1" ) {
									$output .= '<div class="gt-header--panel gt-header--panel_language">';
										$output .= '<div class="gt-inner d-flex align-items-center">';
											$output .= '<div class="container d-flex align-items-center justify-content-between">';
												$output .= '<div class="gt-icons">';
													$output .= '<div class="gt-icon">';
														$output .= '<svg viewBox="0 0 22 22" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <path d="M11,22 C4.92486775,22 0,17.0751322 0,11 C0,4.92486775 4.92486775,0 11,0 C17.0751322,0 22,4.92486775 22,11 C22,17.0751322 17.0751322,22 11,22 Z M11,20 C15.9705627,20 20,15.9705627 20,11 C20,6.02943725 15.9705627,2 11,2 C6.02943725,2 2,6.02943725 2,11 C2,15.9705627 6.02943725,20 11,20 Z M7.99978307,10.9791717 C8.06399619,14.0614835 9.12203221,17.0297279 11.0000219,19.4492318 C12.8779842,17.0301914 13.9360043,14.0660671 14.0002169,11.0208283 C13.9360038,7.93851654 12.8779678,4.97027215 10.9999781,2.5507682 C9.12201578,4.96980861 8.06399569,7.9339329 7.99978307,10.9791717 Z M11.7383452,0.325576969 C14.4031079,3.24290718 15.917487,7.02885486 15.9997831,11.0208283 C15.917487,14.9711451 14.4031079,18.7570928 11.7383452,21.674423 C11.3418249,22.1085257 10.6581751,22.1085257 10.2616548,21.674423 C7.59689209,18.7570928 6.08251301,14.9711451 6.00021693,10.9791717 C6.08251301,7.02885486 7.59689209,3.24290718 10.2616548,0.325576969 C10.6581751,-0.108525656 11.3418249,-0.108525656 11.7383452,0.325576969 Z M1,12 C0.44771525,12 0,11.5522847 0,11 C0,10.4477153 0.44771525,10 1,10 L21,10 C21.5522847,10 22,10.4477153 22,11 C22,11.5522847 21.5522847,12 21,12 L1,12 Z" fill-rule="nonzero"></path> </g> </svg>';
													$output .= '</div>';
												$output .= '</div>';

												$output .= '<div class="gt-content d-flex align-items-center">';
													if ( function_exists( 'icl_register_string' ) ) {

													} elseif( function_exists ( 'nucy_demo_language' ) )  {
														$output .= nucy_demo_language();
													}
												$output .= '</div>';

												$output .= '<div class="gt-icons">';
													$output .= '<div class="gt-icon gt-icon--close">';
														$output .= '<svg viewBox="0 0 14 14" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <path d="M8.41421356,7 L13.7071068,12.2928932 C14.0976311,12.6834175 14.0976311,13.3165825 13.7071068,13.7071068 C13.3165825,14.0976311 12.6834175,14.0976311 12.2928932,13.7071068 L7,8.41421356 L1.70710678,13.7071068 C1.31658249,14.0976311 0.683417511,14.0976311 0.292893219,13.7071068 C-0.0976310729,13.3165825 -0.0976310729,12.6834175 0.292893219,12.2928932 L5.58578644,7 L0.292893219,1.70710678 C-0.0976310729,1.31658249 -0.0976310729,0.683417511 0.292893219,0.292893219 C0.683417511,-0.0976310729 1.31658249,-0.0976310729 1.70710678,0.292893219 L7,5.58578644 L12.2928932,0.292893219 C12.6834175,-0.0976310729 13.3165825,-0.0976310729 13.7071068,0.292893219 C14.0976311,0.683417511 14.0976311,1.31658249 13.7071068,1.70710678 L8.41421356,7 Z"></path> </g> </svg>';
													$output .= '</div>';
												$output .= '</div>';
											$output .= '</div>';
										$output .= '</div>';
									$output .= '</div>';
								}

								if( $header_social_media == "1" ) {
									if( !empty( nucy_social_media_sites() ) ) {
										$output .= '<div class="gt-header--panel gt-header--panel_social">';
											$output .= '<div class="gt-inner d-flex align-items-center">';
												$output .= '<div class="container d-flex align-items-center justify-content-between">';
													$output .= '<div class="gt-icons">';
														$output .= '<div class="gt-icon">';
															$output .= '<svg viewBox="0 0 20 22" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <path d="M16,22 C13.790861,22 12,20.209139 12,18 C12,15.790861 13.790861,14 16,14 C18.209139,14 20,15.790861 20,18 C20,20.209139 18.209139,22 16,22 Z M16,20 C17.1045695,20 18,19.1045695 18,18 C18,16.8954305 17.1045695,16 16,16 C14.8954305,16 14,16.8954305 14,18 C14,19.1045695 14.8954305,20 16,20 Z M4,15 C1.790861,15 0,13.209139 0,11 C0,8.790861 1.790861,7 4,7 C6.209139,7 8,8.790861 8,11 C8,13.209139 6.209139,15 4,15 Z M4,13 C5.1045695,13 6,12.1045695 6,11 C6,9.8954305 5.1045695,9 4,9 C2.8954305,9 2,9.8954305 2,11 C2,12.1045695 2.8954305,13 4,13 Z M13.1580623,6.81485207 L7.0940285,10.353687 C6.61702733,10.6320543 6.00468023,10.4710297 5.72631298,9.9940285 C5.44794572,9.51702733 5.60897033,8.90468023 6.0859715,8.62631298 L12.1496575,5.08768096 C12.0521601,4.7418517 12,4.37701717 12,4 C12,1.790861 13.790861,0 16,0 C18.209139,0 20,1.790861 20,4 C20,6.209139 18.209139,8 16,8 C14.8885419,8 13.8829617,7.54668304 13.1580623,6.81485207 Z M14.3003036,5.05457301 C14.653203,5.62215038 15.2824757,6 16,6 C17.1045695,6 18,5.1045695 18,4 C18,2.8954305 17.1045695,2 16,2 C14.8954305,2 14,2.8954305 14,4 C14,4.34730478 14.0885253,4.67393338 14.2442424,4.9585523 C14.2544289,4.97399233 14.2642499,4.98980034 14.273687,5.0059715 C14.2830553,5.02202467 14.2919259,5.03823114 14.3003036,5.05457301 Z M6.0865223,13.3740082 C5.60934373,13.0959452 5.44792872,12.4837009 5.72599178,12.0065223 C6.00405484,11.5293437 6.61629914,11.3679287 7.0934777,11.6459918 L13.9234777,15.6259918 C14.4006563,15.9040548 14.5620713,16.5162991 14.2840082,16.9934777 C14.0059452,17.4706563 13.3937009,17.6320713 12.9165223,17.3540082 L6.0865223,13.3740082 Z" fill-rule="nonzero"></path> </g> </svg>';
														$output .= '</div>';
													$output .= '</div>';

													$output .= '<div class="gt-content d-flex align-items-center">';
														$output .= nucy_social_media_sites();
													$output .= '</div>';

													$output .= '<div class="gt-icons">';
														$output .= '<div class="gt-icon gt-icon--close">';
															$output .= '<svg viewBox="0 0 14 14" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <path d="M8.41421356,7 L13.7071068,12.2928932 C14.0976311,12.6834175 14.0976311,13.3165825 13.7071068,13.7071068 C13.3165825,14.0976311 12.6834175,14.0976311 12.2928932,13.7071068 L7,8.41421356 L1.70710678,13.7071068 C1.31658249,14.0976311 0.683417511,14.0976311 0.292893219,13.7071068 C-0.0976310729,13.3165825 -0.0976310729,12.6834175 0.292893219,12.2928932 L5.58578644,7 L0.292893219,1.70710678 C-0.0976310729,1.31658249 -0.0976310729,0.683417511 0.292893219,0.292893219 C0.683417511,-0.0976310729 1.31658249,-0.0976310729 1.70710678,0.292893219 L7,5.58578644 L12.2928932,0.292893219 C12.6834175,-0.0976310729 13.3165825,-0.0976310729 13.7071068,0.292893219 C14.0976311,0.683417511 14.0976311,1.31658249 13.7071068,1.70710678 L8.41421356,7 Z"></path> </g> </svg>';
														$output .= '</div>';
													$output .= '</div>';
												$output .= '</div>';
											$output .= '</div>';
										$output .= '</div>';
									}
								}
							$output .= '</div>';
						$output .= '</div>';
					$output .= '</header>';

					return $output;
				}



				/*====== Style 2 ======*/
				function nucy_header_style_2() {
					$output = "";

					$header_language_selector = get_theme_mod( 'nucy_header_language_selector' );
					$header_search = get_theme_mod( 'nucy_header_search', '1' );
					$header_social_media = get_theme_mod( 'nucy_header_social_media', '1' );
					$header_phone_number = get_theme_mod( 'nucy_header_phone_number' );
					$header_working_hours = get_theme_mod( 'nucy_header_working_hours' );
					$header_email_address = get_theme_mod( 'nucy_header_email_address' );
					$header_search = get_theme_mod( 'nucy_header_search', '1' );
					$header_home_icon = get_theme_mod( 'nucy_header_home_icon', '1' );
					$header_sidebar = get_theme_mod( 'nucy_header_sidebar', '1' );
					$header_information = get_theme_mod( 'nucy_header_information', '1' );
					$header_fixed = get_theme_mod( 'nucy_header_fixed', '1' );

					$header_fixed = get_theme_mod( 'nucy_header_fixed', '1' );
					if( $header_fixed == "1" ) {
						$fixed = " ";
					} else {
						$fixed = "";
					}

					$output .= '<header class="gt-header style-2">';
						$output .= '<div class="container">';
							$output .= '<div class="gt-header--inner">';
								$output .= '<div class="gt-header--top d-flex align-items-center">';
									$output .= '<div class="container d-flex align-items-center justify-content-between">';
										
										$output .= nucy_header_elements( $search = "true", $social = "true", $language = "false", $menu = "false" );

										$output .= '<div class="gt-logo d-flex align-items-center justify-content-center">';
											$output .= nucy_header_site_logo();
										$output .= '</div>';

										$output .= nucy_header_elements( $search = "false", $social = "false", $language = "true", $menu = "true" );
									$output .= '</div>';
								$output .= '</div>';

								$output .= '<div class="gt-header--bottom d-flex align-items-center"></div>';

								if( $header_search == "1" ) {
									$output .= '<div class="gt-header--panel gt-header--panel_search">';
										$output .= '<div class="gt-inner d-flex align-items-center">';
											$output .= '<div class="container d-flex align-items-center justify-content-between">';
												$output .= '<div class="gt-icons">';
													$output .= '<div class="gt-icon">';
														$output .= '<svg viewBox="0 0 20 20" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <path d="M19.7071068,18.2928932 C20.0976311,18.6834175 20.0976311,19.3165825 19.7071068,19.7071068 C19.3165825,20.0976311 18.6834175,20.0976311 18.2928932,19.7071068 L13.9428932,15.3571068 C13.5523689,14.9665825 13.5523689,14.3334175 13.9428932,13.9428932 C14.3334175,13.5523689 14.9665825,13.5523689 15.3571068,13.9428932 L19.7071068,18.2928932 Z M9,18 C4.02943725,18 0,13.9705627 0,9 C0,4.02943725 4.02943725,0 9,0 C13.9705627,0 18,4.02943725 18,9 C18,13.9705627 13.9705627,18 9,18 Z M9,16 C12.8659932,16 16,12.8659932 16,9 C16,5.13400675 12.8659932,2 9,2 C5.13400675,2 2,5.13400675 2,9 C2,12.8659932 5.13400675,16 9,16 Z" fill-rule="nonzero"></path> </g> </svg>';
													$output .= '</div>';
												$output .= '</div>';

												$output .= '<div class="gt-content d-flex align-items-center">';
													$output .= '<div class="gt-search--form">';
														$output .= '<form role="search" method="get" class="searchform" action="' . esc_url( home_url( '/' ) ) . '">';
															$output .= '<input type="text" value="' . esc_attr( get_search_query() ) . '" placeholder="' . esc_attr__( 'Enter the keyword...', 'nucy' ) . '" name="s" class="searchform-text" />';
														$output .= '</form>';
													$output .= '</div>';
												$output .= '</div>';

												$output .= '<div class="gt-icons">';
													$output .= '<div class="gt-icon gt-icon--close">';
														$output .= '<svg viewBox="0 0 14 14" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <path d="M8.41421356,7 L13.7071068,12.2928932 C14.0976311,12.6834175 14.0976311,13.3165825 13.7071068,13.7071068 C13.3165825,14.0976311 12.6834175,14.0976311 12.2928932,13.7071068 L7,8.41421356 L1.70710678,13.7071068 C1.31658249,14.0976311 0.683417511,14.0976311 0.292893219,13.7071068 C-0.0976310729,13.3165825 -0.0976310729,12.6834175 0.292893219,12.2928932 L5.58578644,7 L0.292893219,1.70710678 C-0.0976310729,1.31658249 -0.0976310729,0.683417511 0.292893219,0.292893219 C0.683417511,-0.0976310729 1.31658249,-0.0976310729 1.70710678,0.292893219 L7,5.58578644 L12.2928932,0.292893219 C12.6834175,-0.0976310729 13.3165825,-0.0976310729 13.7071068,0.292893219 C14.0976311,0.683417511 14.0976311,1.31658249 13.7071068,1.70710678 L8.41421356,7 Z"></path> </g> </svg>';
													$output .= '</div>';
												$output .= '</div>';
											$output .= '</div>';
										$output .= '</div>';
									$output .= '</div>';
								}

								if( $header_language_selector == "1" ) {
									$output .= '<div class="gt-header--panel gt-header--panel_language">';
										$output .= '<div class="gt-inner d-flex align-items-center">';
											$output .= '<div class="container d-flex align-items-center justify-content-between">';
												$output .= '<div class="gt-icons">';
													$output .= '<div class="gt-icon">';
														$output .= '<svg viewBox="0 0 22 22" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <path d="M11,22 C4.92486775,22 0,17.0751322 0,11 C0,4.92486775 4.92486775,0 11,0 C17.0751322,0 22,4.92486775 22,11 C22,17.0751322 17.0751322,22 11,22 Z M11,20 C15.9705627,20 20,15.9705627 20,11 C20,6.02943725 15.9705627,2 11,2 C6.02943725,2 2,6.02943725 2,11 C2,15.9705627 6.02943725,20 11,20 Z M7.99978307,10.9791717 C8.06399619,14.0614835 9.12203221,17.0297279 11.0000219,19.4492318 C12.8779842,17.0301914 13.9360043,14.0660671 14.0002169,11.0208283 C13.9360038,7.93851654 12.8779678,4.97027215 10.9999781,2.5507682 C9.12201578,4.96980861 8.06399569,7.9339329 7.99978307,10.9791717 Z M11.7383452,0.325576969 C14.4031079,3.24290718 15.917487,7.02885486 15.9997831,11.0208283 C15.917487,14.9711451 14.4031079,18.7570928 11.7383452,21.674423 C11.3418249,22.1085257 10.6581751,22.1085257 10.2616548,21.674423 C7.59689209,18.7570928 6.08251301,14.9711451 6.00021693,10.9791717 C6.08251301,7.02885486 7.59689209,3.24290718 10.2616548,0.325576969 C10.6581751,-0.108525656 11.3418249,-0.108525656 11.7383452,0.325576969 Z M1,12 C0.44771525,12 0,11.5522847 0,11 C0,10.4477153 0.44771525,10 1,10 L21,10 C21.5522847,10 22,10.4477153 22,11 C22,11.5522847 21.5522847,12 21,12 L1,12 Z" fill-rule="nonzero"></path> </g> </svg>';
													$output .= '</div>';
												$output .= '</div>';

												$output .= '<div class="gt-content d-flex align-items-center">';
													if ( function_exists ( 'icl_register_string' ) ) {

													} elseif( function_exists( 'nucy_demo_language' ) )  {
														$output .= nucy_demo_language();
													}
												$output .= '</div>';

												$output .= '<div class="gt-icons">';
													$output .= '<div class="gt-icon gt-icon--close">';
														$output .= '<svg viewBox="0 0 14 14" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <path d="M8.41421356,7 L13.7071068,12.2928932 C14.0976311,12.6834175 14.0976311,13.3165825 13.7071068,13.7071068 C13.3165825,14.0976311 12.6834175,14.0976311 12.2928932,13.7071068 L7,8.41421356 L1.70710678,13.7071068 C1.31658249,14.0976311 0.683417511,14.0976311 0.292893219,13.7071068 C-0.0976310729,13.3165825 -0.0976310729,12.6834175 0.292893219,12.2928932 L5.58578644,7 L0.292893219,1.70710678 C-0.0976310729,1.31658249 -0.0976310729,0.683417511 0.292893219,0.292893219 C0.683417511,-0.0976310729 1.31658249,-0.0976310729 1.70710678,0.292893219 L7,5.58578644 L12.2928932,0.292893219 C12.6834175,-0.0976310729 13.3165825,-0.0976310729 13.7071068,0.292893219 C14.0976311,0.683417511 14.0976311,1.31658249 13.7071068,1.70710678 L8.41421356,7 Z"></path> </g> </svg>';
													$output .= '</div>';
												$output .= '</div>';
											$output .= '</div>';
										$output .= '</div>';
									$output .= '</div>';
								}

								if( $header_social_media == "1" ) {
									if( !empty( nucy_social_media_sites() ) ) {
										$output .= '<div class="gt-header--panel gt-header--panel_social">';
											$output .= '<div class="gt-inner d-flex align-items-center">';
												$output .= '<div class="container d-flex align-items-center justify-content-between">';
													$output .= '<div class="gt-icons">';
														$output .= '<div class="gt-icon">';
															$output .= '<svg viewBox="0 0 20 22" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <path d="M16,22 C13.790861,22 12,20.209139 12,18 C12,15.790861 13.790861,14 16,14 C18.209139,14 20,15.790861 20,18 C20,20.209139 18.209139,22 16,22 Z M16,20 C17.1045695,20 18,19.1045695 18,18 C18,16.8954305 17.1045695,16 16,16 C14.8954305,16 14,16.8954305 14,18 C14,19.1045695 14.8954305,20 16,20 Z M4,15 C1.790861,15 0,13.209139 0,11 C0,8.790861 1.790861,7 4,7 C6.209139,7 8,8.790861 8,11 C8,13.209139 6.209139,15 4,15 Z M4,13 C5.1045695,13 6,12.1045695 6,11 C6,9.8954305 5.1045695,9 4,9 C2.8954305,9 2,9.8954305 2,11 C2,12.1045695 2.8954305,13 4,13 Z M13.1580623,6.81485207 L7.0940285,10.353687 C6.61702733,10.6320543 6.00468023,10.4710297 5.72631298,9.9940285 C5.44794572,9.51702733 5.60897033,8.90468023 6.0859715,8.62631298 L12.1496575,5.08768096 C12.0521601,4.7418517 12,4.37701717 12,4 C12,1.790861 13.790861,0 16,0 C18.209139,0 20,1.790861 20,4 C20,6.209139 18.209139,8 16,8 C14.8885419,8 13.8829617,7.54668304 13.1580623,6.81485207 Z M14.3003036,5.05457301 C14.653203,5.62215038 15.2824757,6 16,6 C17.1045695,6 18,5.1045695 18,4 C18,2.8954305 17.1045695,2 16,2 C14.8954305,2 14,2.8954305 14,4 C14,4.34730478 14.0885253,4.67393338 14.2442424,4.9585523 C14.2544289,4.97399233 14.2642499,4.98980034 14.273687,5.0059715 C14.2830553,5.02202467 14.2919259,5.03823114 14.3003036,5.05457301 Z M6.0865223,13.3740082 C5.60934373,13.0959452 5.44792872,12.4837009 5.72599178,12.0065223 C6.00405484,11.5293437 6.61629914,11.3679287 7.0934777,11.6459918 L13.9234777,15.6259918 C14.4006563,15.9040548 14.5620713,16.5162991 14.2840082,16.9934777 C14.0059452,17.4706563 13.3937009,17.6320713 12.9165223,17.3540082 L6.0865223,13.3740082 Z" fill-rule="nonzero"></path> </g> </svg>';
														$output .= '</div>';
													$output .= '</div>';

													$output .= '<div class="gt-content d-flex align-items-center">';
														$output .= nucy_social_media_sites();
													$output .= '</div>';

													$output .= '<div class="gt-icons">';
														$output .= '<div class="gt-icon gt-icon--close">';
															$output .= '<svg viewBox="0 0 14 14" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <path d="M8.41421356,7 L13.7071068,12.2928932 C14.0976311,12.6834175 14.0976311,13.3165825 13.7071068,13.7071068 C13.3165825,14.0976311 12.6834175,14.0976311 12.2928932,13.7071068 L7,8.41421356 L1.70710678,13.7071068 C1.31658249,14.0976311 0.683417511,14.0976311 0.292893219,13.7071068 C-0.0976310729,13.3165825 -0.0976310729,12.6834175 0.292893219,12.2928932 L5.58578644,7 L0.292893219,1.70710678 C-0.0976310729,1.31658249 -0.0976310729,0.683417511 0.292893219,0.292893219 C0.683417511,-0.0976310729 1.31658249,-0.0976310729 1.70710678,0.292893219 L7,5.58578644 L12.2928932,0.292893219 C12.6834175,-0.0976310729 13.3165825,-0.0976310729 13.7071068,0.292893219 C14.0976311,0.683417511 14.0976311,1.31658249 13.7071068,1.70710678 L8.41421356,7 Z"></path> </g> </svg>';
														$output .= '</div>';
													$output .= '</div>';
												$output .= '</div>';
											$output .= '</div>';
										$output .= '</div>';
									}
								}
							$output .= '</div>';
						$output .= '</div>';
					$output .= '</header>';

					return $output;
				}



			/*====== Header Style Selector ======*/
			if( $header_status == '1' ) {
				if( $header_style == "style-2" ) {
					echo nucy_header_style_2();
				} elseif( $header_style == "style-3" ) {
					echo nucy_header_style_1();
				} else {
					echo nucy_header_style_1();
				}
			}

		}
	}



	/*======
	*
	* Fixed Header
	*
	======*/
	function nucy_fixed_header() {
		$output = "";

		$header_home_icon = get_theme_mod( 'nucy_header_home_icon', '1' );
		$header_sidebar = get_theme_mod( 'nucy_header_sidebar', '1' );
		$header_fixed = get_theme_mod( 'nucy_header_fixed', '1' );

		if( $header_fixed == "1" ) {
			$output .= '<div class="gt-header--fixed">';
				$output .= '<div class="gt-inner d-flex align-items-center">';
					$output .= '<div class="container d-flex align-items-center justify-content-between">';
						if( $header_home_icon == "1" ) {
							$output .= '<div class="gt-icons">';
								$output .= '<div class="gt-icon">';
									$output .= '<a href="' . esc_url( home_url( '/' ) ) . '" class="site-logo" title="' . esc_attr__( 'Home', 'nucy' ) . '">';
										$output .= '<svg viewBox="0 0 20 22" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <path d="M2,8.48908381 L2,19 C2,19.5522847 2.44771525,20 3,20 L17,20 C17.5522847,20 18,19.5522847 18,19 L18,8.48908381 L10,2.26686158 L2,8.48908381 Z M0.386059386,7.21064778 L9.38605939,0.210647783 C9.74716987,-0.0702159275 10.2528301,-0.0702159275 10.6139406,0.210647783 L19.6139406,7.21064778 C19.8575272,7.40010398 20,7.69140957 20,8 L20,19 C20,20.6568542 18.6568542,22 17,22 L3,22 C1.34314575,22 0,20.6568542 0,19 L0,8 C0,7.69140957 0.142472844,7.40010398 0.386059386,7.21064778 Z M8,12 L8,21 C8,21.5522847 7.55228475,22 7,22 C6.44771525,22 6,21.5522847 6,21 L6,11 C6,10.4477153 6.44771525,10 7,10 L13,10 C13.5522847,10 14,10.4477153 14,11 L14,21 C14,21.5522847 13.5522847,22 13,22 C12.4477153,22 12,21.5522847 12,21 L12,12 L8,12 Z" fill-rule="nonzero"></path> </g> </svg>';
									$output .= '</a>';
								$output .= '</div>';
							$output .= '</div>';
						}

						$output .= nucy_navbar_style_1();


						if( $header_sidebar == "1" ) {
							if ( is_active_sidebar( 'nucy-header-sidebar' ) ) {
								$output .= '<div class="gt-icons">';
									$output .= '<div class="gt-icon gt-icon--side-panel-open">';
										$output .= '<svg viewBox="0 0 18 4" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g fill-rule="evenodd"><path d="M16,4 C14.8954305,4 14,3.1045695 14,2 C14,0.8954305 14.8954305,0 16,0 C17.1045695,0 18,0.8954305 18,2 C18,3.1045695 17.1045695,4 16,4 Z M9,4 C7.8954305,4 7,3.1045695 7,2 C7,0.8954305 7.8954305,0 9,0 C10.1045695,0 11,0.8954305 11,2 C11,3.1045695 10.1045695,4 9,4 Z M2,4 C0.8954305,4 0,3.1045695 0,2 C0,0.8954305 0.8954305,0 2,0 C3.1045695,0 4,0.8954305 4,2 C4,3.1045695 3.1045695,4 2,4 Z"></path></g></svg>';
									$output .= '</div>';
								$output .= '</div>';
							}
						}
					$output .= '</div>';
				$output .= '</div>';
			$output .= '</div>';
		}

		return $output;
	}



	/*======
	*
	* Mobile Header
	*
	======*/
	function nucy_mobile_header() {
		$output = '<header class="gt-header-mobile">';
			$output .= '<div class="gt-header-mobile--inner d-flex align-items-center">';
				$output .= '<div class="container d-flex align-items-center justify-content-between">';
					$output .= '<div class="gt-logo">';
						$output .= nucy_header_site_logo();
					$output .= '</div>';

					$mobile_menu = wp_nav_menu(
						array(
							'theme_location' => 'main-menu',
							'depth' => 5,
							'container' => 'ul',
							'fallback_cb' => 'nucy_walker::fallback',
							'walker' => new nucy_walker(),
							'echo' => false
						)
					);

					if( !empty( $mobile_menu ) ) {
						$output .= '<div class="gt-icons d-flex align-items-center justify-content-end">';
							$output .= '<div class="gt-icon gt-icon--mmenu">';
								$output .= '<svg viewBox="0 0 20 14" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g> <path d="M1,14 C0.44771525,14 0,13.5522847 0,13 C0,12.4477153 0.44771525,12 1,12 L19,12 C19.5522847,12 20,12.4477153 20,13 C20,13.5522847 19.5522847,14 19,14 L1,14 Z M1,2 C0.44771525,2 0,1.55228475 0,1 C0,0.44771525 0.44771525,0 1,0 L19,0 C19.5522847,0 20,0.44771525 20,1 C20,1.55228475 19.5522847,2 19,2 L1,2 Z M1,8 C0.44771525,8 0,7.55228475 0,7 C0,6.44771525 0.44771525,6 1,6 L19,6 C19.5522847,6 20,6.44771525 20,7 C20,7.55228475 19.5522847,8 19,8 L1,8 Z"></path> </g> </svg>';
							$output .= '</div>';
						$output .= '</div>';						
					}
				$output .= '</div>';
			$output .= '</div>';
		$output .= '</header>';

		$output .= '<div class="gt-mobile-menu">';
			$output .= '<div class="gt-inner">';
				$output .= '<div class="scroll-pane">';
					$output .= '<div class="gt-logo">';
						$output .= nucy_header_site_logo();
					$output .= '</div>';
					$output .= '<nav class="gt-mobile-navbar">';
						$output .= wp_nav_menu(
							array(
								'theme_location' => 'main-menu',
								'depth' => 5,
								'container' => 'ul',
								'fallback_cb' => 'nucy_walker::fallback',
								'walker' => new nucy_walker(),
								'echo' => false
							)
						);
					$output .= '</nav>';
				$output .= '</div>';
			$output .= '</div>';
		$output .= '</div>';

		return $output;
	}



	/*======
	*
	* Footer
	*
	======*/
	function nucy_footer() {
		$output = "";
		$footer_status = get_theme_mod( 'nucy_footer_status', '1' );
		$footer_content_page = get_theme_mod( 'nucy_footer_content_page' );
		$footer_newsletter = get_theme_mod( 'nucy_footer_newsletter', '1' );
		$footer_newsletter_code = get_theme_mod( 'nucy_footer_newsletter_code' );
		$footer_go_top = get_theme_mod( 'nucy_footer_go_top', '1' );
		$footer_menu = get_theme_mod( 'nucy_footer_menu', '1' );
		$copyright = get_theme_mod( 'nucy_copyright', '1' );
		$copyright_menu = get_theme_mod( 'nucy_copyright_menu', '1' );
		$copyright_logo = get_theme_mod( 'nucy_copyright_logo' );
		$copyright_text = get_theme_mod( 'nucy_copyright_text' );
		$cookie_bar_status = get_theme_mod( 'nucy_cookie_status', '1' );
    	$cookie_language = get_theme_mod( 'nucy_cookie_language' );
    	$cookie_style = get_theme_mod( 'nucy_cookie_style', '1' );
    	$google_analytics = get_theme_mod( 'nucy_google_analytics' );
    	$hotjar_analytics = get_theme_mod( 'nucy_hotjar_analytics' );
        $facebook_pixel = get_theme_mod( 'nucy_facebook_pixel' );
        $cookie_policy_page = get_theme_mod( 'nucy_cookie_policy_page' );
        $cookie_hide_after = get_theme_mod( 'nucy_cookie_hide_after', '1' );
        $cookie_position = get_theme_mod( 'nucy_cookie_position' );
        $cookie_banner_description = get_theme_mod( 'nucy_banner_description' );
        $cookie_banner_link_text = get_theme_mod( 'nucy_banner_link_text' );
        $cookie_banner_background = get_theme_mod('nucy_cookie_banner_background');
        $cookie_banner_color = get_theme_mod('nucy_cookie_banner_color');
        $cookie_banner_heading = get_theme_mod('nucy_cookie_banner_heading');
        $cookie_accept_button_text = get_theme_mod('nucy_cookie_accept_button_text');
        $cookie_accept_button_color = get_theme_mod('nucy_cookie_accept_button_color');
        $cookie_accept_button_background = get_theme_mod('nucy_cookie_accept_button_background');
        $cookie_reject_button_text = get_theme_mod('nucy_cookie_reject_button_text');
        $cookie_reject_button_color = get_theme_mod('nucy_cookie_reject_button_color');
        $cookie_reject_button_background = get_theme_mod('nucy_cookie_reject_button_background');
        $cookie_manage_button_text = get_theme_mod('nucy_cookie_manage_button_text');
        $cookie_manage_button_color = get_theme_mod('nucy_cookie_manage_button_color');
        $cookie_manage_button_background = get_theme_mod('nucy_cookie_manage_button_background');

		if( $footer_status == '1' ) {
			$output .= '<footer class="gt-footer">';
				$output .= '<div class="gt-footer-wrapper">';
					$output .= '<div class="gt-footer--inner">';
						if( !empty( $footer_content_page ) ) {
							$output .= '<div class="gt-footer--boxes">';
								$output .= '<div class="container">';
									$output .= '<div class="row">';
										$args = array(
											'p' => $footer_content_page,
											'ignore_sticky_posts' => true,
											'post_type' => 'page',
											'post_status' => 'publish'
										);
										$wp_query = new WP_Query( $args );
										while ( $wp_query->have_posts() ) {
											if ( $wp_query->have_posts() ) {
												$wp_query->the_post();
												$output .= do_shortcode( get_the_content( get_the_ID() ) );
											}
										}
										wp_reset_postdata();
									$output .= '</div>';
								$output .= '</div>';
							$output .= '</div>';
						}

						if( $footer_menu == "1" or $copyright == "1" or !empty( $copyright_logo ) or !empty( $copyright_text ) or $copyright_menu == "1" or $footer_newsletter == "1" and !empty( $footer_newsletter_code ) ) {
							$output .= '<div class="gt-footer--top-wrapper">';
								if( $footer_menu == "1" or $footer_newsletter == "1" and !empty( $footer_newsletter_code ) ) {
									$output .= '<div class="gt-footer--top d-flex align-items-center">';
										$output .= '<div class="container d-flex align-items-center justify-content-between flex-lg-row flex-column">';
											if( $footer_menu == "1" ) {
												$output .= wp_nav_menu(
													array(
														'menu' => 'footer-menu',
														'theme_location' => 'footer-menu',
														'depth' => 1,
														'menu_class' => 'nav justify-content-center',
														'fallback_cb' => 'nucy_walker::fallback',
														'walker' => new nucy_walker(),
														'echo' => false
													)
												);
											}

											if( $footer_newsletter == "1" and !empty( $footer_newsletter_code ) ) {
												$output .= '<div class="gt-newsletter d-flex align-items-center">';
													$output .= '<div class="d-flex align-items-center justify-content-center justify-content-lg-start">';
														$output .= '<div class="gt-newsletter--box d-flex align-items-center flex-lg-row flex-column">';
															$output .= '<div class="gt-icons">';
																$output .= '<div class="gt-icon">';
																	$output .= '<svg viewBox="0 0 18 16" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <g fill="#000000" fill-rule="nonzero"> <path d="M5.58578644,7 L0.292893219,1.70710678 C-0.0976310729,1.31658249 -0.0976310729,0.683417511 0.292893219,0.292893219 C0.683417511,-0.0976310729 1.31658249,-0.0976310729 1.70710678,0.292893219 L7.70710678,6.29289322 C8.09763107,6.68341751 8.09763107,7.31658249 7.70710678,7.70710678 L1.70710678,13.7071068 C1.31658249,14.0976311 0.683417511,14.0976311 0.292893219,13.7071068 C-0.0976310729,13.3165825 -0.0976310729,12.6834175 0.292893219,12.2928932 L5.58578644,7 Z M9,16 C8.44771525,16 8,15.5522847 8,15 C8,14.4477153 8.44771525,14 9,14 L17,14 C17.5522847,14 18,14.4477153 18,15 C18,15.5522847 17.5522847,16 17,16 L9,16 Z"></path> </g> </g> </svg>';
																$output .= '</div>';
															$output .= '</div>';

															if( !empty( $footer_newsletter_code ) ) {
																$output .= do_shortcode( get_theme_mod( 'nucy_footer_newsletter_code' ) );
															}
														$output .= '</div>';
													$output .= '</div>';
												$output .= '</div>';
											}
										$output .= '</div>';
									$output .= '</div>';
								}
							$output .= '</div>';

							if( $copyright == "1" ) {
								if( !empty( $copyright_logo ) or !empty( $copyright_text ) or $copyright_menu == "1" ) {
									$output .= '<div class="gt-footer--bottom d-flex align-items-center">';
										$output .= '<div class="container d-flex align-items-center justify-content-between flex-lg-row flex-column">';
											if( !empty( $copyright_logo ) ) {
												$output .= '<div class="gt-logo">';
													$output .= '<a href="' . esc_url( home_url( '/' ) ) . '" title="' . esc_attr( get_bloginfo( 'name' ) ) . '">';
														$output .= '<img alt="' . esc_attr( get_bloginfo( 'name' ) ) . '" src="' . esc_url( wp_get_attachment_url( $copyright_logo ) ) . '" />';
													$output .= '</a>';
												$output .= '</div>';
											}

											if( !empty( $copyright_text ) ) {
												$output .= '<div class="gt-copyright">';
													$output .= '<span>';
														$output .= get_theme_mod( 'nucy_copyright_text' );
													$output .= '</span>';
												$output .= '</div>';
											}

											if( $copyright_menu == "1" ) {
												$output .= wp_nav_menu(
													array(
														'menu' => 'copyright-menu',
														'theme_location' => 'copyright-menu',
														'depth' => 1,
														'menu_class' => 'nav',
														'fallback_cb' => 'nucy_walker::fallback',
														'walker' => new nucy_walker(),
														'echo' => false
													)
												);
											}
										$output .= '</div>';
									$output .= '</div>';
								}
							}
						}
					$output .= '</div>';
				$output .= '</div>';
    				if ( $cookie_bar_status == '1' ){
            			echo '<script>';
                            echo 'glowCookies.start(      "' . $cookie_language . '", { ';
                                echo 'style:               ' . $cookie_style . ', ';
                                echo 'analytics:          "' . $google_analytics .'", ';
                                echo 'HotjarTrackingCode: "' . $hotjar_analytics .'", ';
                                echo 'facebookPixel:      "' . $facebook_pixel .'", ';
                                echo 'policyLink:         "' . $cookie_policy_page .'", ';
                                echo 'hideAfterClick:      ' . $cookie_hide_after .', ';
                                echo 'position:           "' . $cookie_position .'", ';
                                echo 'bannerDescription:  "' . $cookie_banner_description .'",';
                                echo 'bannerLinkText:     "' . $cookie_banner_link_text .'",';
                                echo 'bannerBackground:   "' . $cookie_banner_background .'",';
                                echo 'bannerColor:        "' . $cookie_banner_color .'",';
                                echo 'bannerHeading:      "' . $cookie_banner_heading .'",';
                                echo 'acceptBtnText:      "' . $cookie_accept_button_text .'",';
                                echo 'acceptBtnColor:     "' . $cookie_accept_button_color .'",';
                                echo 'acceptBtnBackground:"' . $cookie_accept_button_background .'",';
                                echo 'rejectBtnText:      "' . $cookie_reject_button_text .'",';
                                echo 'rejectBtnColor:     "' . $cookie_reject_button_color .'",';
                                echo 'rejectBtnBackground:"' . $cookie_reject_button_background .'",';
                                echo 'manageText:         "' . $cookie_manage_button_text .'",';
                                echo 'manageColor:        "' . $cookie_manage_button_color .'",';
                                echo 'manageBackground:   "' . $cookie_manage_button_background .'"';
                                    
                            echo '});';
                        echo '</script>';
    			    }
			$output .= '</footer>';
		}

		return $output;
	}



	/*======
	*
	* Add Footer Actions
	*
	======*/
		/*====== Sidebar Header ======*/
		function nucy_sidebar_header() {
			if ( is_active_sidebar( 'nucy-header-sidebar' ) ) {
				echo '<div class="gt-side-panel">';
					echo '<div class="gt-side-panel--inner">';
						echo '<div class="scroll-pane">';
							dynamic_sidebar( 'nucy-header-sidebar' );
						echo '</div>';
					echo '</div>';
				echo '</div>';
			}
		}
		add_action( 'wp_footer', 'nucy_sidebar_header' );



		/*====== Wrapper BG Popups ======*/
		function nucy_bg_wrapper_popups() {
			echo '<div class="gt-overlay">';
				echo '<div class="gt-overlay--close"></div>';
			echo '</div>';
		}
		add_action( 'wp_footer', 'nucy_bg_wrapper_popups' );



	/*======
	*
	* Titles
	*
	======*/
	function nucy_heading( $title = "", $top_title = "", $text = "", $align = "" ) {
		$output = "";

		/*====== Align ======*/
		if( !empty( $atts["align"] ) ) {
			$align = 'text-' . esc_attr( $atts["align"] );
		} else {
			$align = "text-left";
		}

		if( !empty( $title ) ) {
			$output .= '<div class="gt-section-heading text-center ' . esc_attr( $align ) . '">';
				$output .= '<div class="gt-box">';
					$output .= '<div class="gt-box--line"></div>';
					if( !empty( $top_title ) ) {
						$output .= '<div class="gt-box--subtitle">' . esc_attr( $top_title ) . '</div>';
					}

					if( !empty( $title ) ) {
						$output .= '<div class="gt-box--title">' . esc_attr( $title ) . '</div>';
					}

					if( !empty( $text ) ) {
						$output .= '<div class="gt-box--content">';
							$output .= '<p>' . esc_attr( $text ) . '</p>';
						$output .= '</div>';
					}
				$output .= '</div>';
			$output .= '</div>';
		}

		return $output;
	}



	/*======
	*
	* Breadcrumb
	*
	======*/
	function nucy_breadcrumb() {
		if( function_exists( 'bcn_display' ) ) {
			$output = '<section class="gt-page-breadcrumb">';
				$output .= '<div class="gt--inner d-flex align-items-center">';
					$output .= '<div class="container d-flex align-items-center justify-content-start">';
						$output .= '<div class="gt-icons d-flex align-items-center">';
							$output .= '<div class="gt-icon d-flex align-items-center">';
								$output .= '<i class="fas fa-angle-double-right"></i>';
							$output .= '</div>';
						$output .= '</div>';
						$output .= '<nav aria-label="breadcrumb">';
							$output .= '<ol class="breadcrumb">';
								$output .= bcn_display_list( $return = true );
							$output .= '</ol>';
						$output .= '</nav>';
					$output .= '</div>';
				$output .= '</div>';
			$output .= '</section>';
			return $output;
		}
	}



	/*======
	*
	* Header Slider
	*
	======*/
	function nucy_page_header_slider() {
		$output = "";

		if ( function_exists( 'rwmb_meta' ) ) {
			$slider_header = rwmb_meta( 'slider-header' );
			$slider_header_speed = rwmb_meta( 'slider-header-slide-speed' );
			$slider_header_b_style = rwmb_meta( 'slider-header-button-style' );
			$slider_header_slides = rwmb_meta( 'slider-header-slides' );

			/*====== Button Style ======*/
			if( !empty( $slider_header_b_style ) ) {
				$button_style = 'gt-btn-' . esc_attr( $slider_header_b_style );
			} else {
				$button_style = "gt-btn-style-1";
			}

			if( $slider_header == "1" ) {
				if( !empty( $slider_header_slides ) ) {
					$output .= '<section class="gt-slider">';
						$output .= '<div class="gt-inner">';
							$output .= '<div class="swiper-container gt-main-slider gt-swiper-slider" data-gt-speed="600" data-gt-parallax="true" data-gt-direction="horizontal" data-gt-item="1" data-gt-item-space="0" data-gt-loop="true">';
								$output .= '<div class="swiper-wrapper">';
									foreach ( $slider_header_slides as $item ) {
										if( !empty( $item ) ) {
											if( !empty( $item["image"] ) or !empty( $item["top-title"] ) or !empty( $item["title"] ) or !empty( $item["text"] ) ) {
												$output .= '<div class="swiper-slide">';
													/*====== Background Image ======*/
													if( !empty( $item["image"] ) ) {
														foreach( $item["image"] as $s_image ) {
															if( !empty( $s_image ) ) {
																$image = wp_get_attachment_image_url( esc_attr( $s_image ), 'nucy-slider-1', true );
															} else {
																$image = "";
															}
														}
													} else {
														$image = "";
													}

													$output .= '<div class="swiper-slide--image" data-swiper-parallax-x="400" style="background-image: url(' . esc_url( $image ) .  ');"></div>';
													$output .= '<div class="swiper-slide--caption" data-swiper-parallax-x="300">';
														$output .= '<div class="gt-box">';
															if( !empty( $item["top-title"] ) ) {
																$output .= '<div class="gt-box--subtitle">' . esc_attr( $item["top-title"] ) . '</div>';
															}

															if( !empty( $item["title"] ) ) {
																$output .= '<div class="gt-box--title">' . esc_attr( $item["title"] ) . '</div>';
															}

															if( !empty( $item["text"] ) ) {
																$output .= '<p>' . esc_attr( $item["text"] ) . '</p>';
															}

															if( !empty( $item["button-link"] ) ) {
																if( !empty( $item["button-target"] ) ) {
																	$target = $item["button-target"];
																} else {
																	$target = "_self";
																}

																$output .= '<a href="' . esc_url( $item["button-link"] ) . '" title="' . esc_attr( $item["button-text"] ) . '" class="btn ' . esc_attr( $button_style ) . '" target="' . esc_attr( $target ) . '">' . esc_attr( $item["button-text"] ) . '</a>';
															}
														$output .= '</div>';
													$output .= '</div>';
												$output .= '</div>';
											}
										}
									}
								$output .= '</div>';

								$output .= '<div class="gt-slider-controls gt-dark">';
									$output .= '<div class="gt-slider-button gt-slider-prev">';
										$output .= '<span class="text">' . esc_html__( 'Prev', 'nucy' ) . '</span>';
										$output .= '<span class="line"></span>';
									$output .= '</div>';
									$output .= '<div class="swiper-pagination"></div>';
									$output .= '<div class="gt-slider-button gt-slider-next">';
										$output .= '<span class="line"></span>';
										$output .= '<span class="text">' . esc_html__( 'Next', 'nucy' ) . '</span>';
									$output .= '</div>';
								$output .= '</div>';
							$output .= '</div>';
						$output .= '</div>';
					$output .= '</section>';

					return $output;
				}
			}
		}
	}



	/*======
	*
	* Page Banner
	*
	======*/
	function nucy_page_banner( $title = "", $top_text = "", $bottom_text = "", $custom_background = "", $google_map = "", $map_lat = "", $map_lng = "", $map_title = "" ) {
		$output = "";
		if( !empty( $custom_background ) ) {
			foreach ( $custom_background as $bg ) {
				$bg_id = $bg["ID"];
			}
		} else {
			$bg_id = "";
		}

		if( $google_map == "1" and !empty( $map_lat ) and !empty( $map_lng ) ) {
				$nucy_google_map_api = get_theme_mod( 'nucy_google_map_api' );
				if( !empty( $nucy_google_map_api ) ) {
					$map_url = 'https://maps.googleapis.com/maps/api/js?key=' . ( $nucy_google_map_api ) . '&callback=initMap';
					wp_enqueue_script( 'google-map', $map_url, array(), false, true );			
				}

				$map_icon = get_template_directory_uri() . '/include/assets/img/mapicon.svg';
				$output .= '<section class="gt-page-banner gt-page-banner-contact-map">';
					$output .= '<div id="map"></div>';
						wp_add_inline_script( "nucy", '
			                function initMap() {
			                    var myLatLng = {lat: ' . esc_attr( $map_lat ) . ', lng: ' . esc_attr( $map_lng ) . '};

			                    var map = new google.maps.Map(document.getElementById("map"), {
			                        zoom: 12,
			                        center: myLatLng,
			                        scrollwheel: false,
			                        panControl: false,
			                        styles: [
			                            {
			                                "elementType": "geometry",
			                                "stylers": [
			                                    {
			                                        "color": "#f5f5f5"
			                                    }
			                                ]
			                            },
			                            {
			                                "elementType": "labels.icon",
			                                "stylers": [
			                                    {
			                                        "visibility": "off"
			                                    }
			                                ]
			                            },
			                            {
			                                "elementType": "labels.text.fill",
			                                "stylers": [
			                                    {
			                                        "color": "#616161"
			                                    }
			                                ]
			                            },
			                            {
			                                "elementType": "labels.text.stroke",
			                                "stylers": [
			                                    {
			                                        "color": "#f5f5f5"
			                                    }
			                                ]
			                            },
			                            {
			                                "featureType": "administrative.land_parcel",
			                                "elementType": "labels.text.fill",
			                                "stylers": [
			                                    {
			                                        "color": "#bdbdbd"
			                                    }
			                                ]
			                            },
			                            {
			                                "featureType": "poi",
			                                "elementType": "geometry",
			                                "stylers": [
			                                    {
			                                        "color": "#eeeeee"
			                                    }
			                                ]
			                            },
			                            {
			                                "featureType": "poi",
			                                "elementType": "labels.text.fill",
			                                "stylers": [
			                                    {
			                                        "color": "#757575"
			                                    }
			                                ]
			                            },
			                            {
			                                "featureType": "poi.park",
			                                "elementType": "geometry",
			                                "stylers": [
			                                    {
			                                        "color": "#e5e5e5"
			                                    }
			                                ]
			                            },
			                            {
			                                "featureType": "poi.park",
			                                "elementType": "labels.text.fill",
			                                "stylers": [
			                                    {
			                                        "color": "#9e9e9e"
			                                    }
			                                ]
			                            },
			                            {
			                                "featureType": "road",
			                                "elementType": "geometry",
			                                "stylers": [
			                                    {
			                                        "color": "#ffffff"
			                                    }
			                                ]
			                            },
			                            {
			                                "featureType": "road.arterial",
			                                "elementType": "labels.text.fill",
			                                "stylers": [
			                                    {
			                                        "color": "#757575"
			                                    }
			                                ]
			                            },
			                            {
			                                "featureType": "road.highway",
			                                "elementType": "geometry",
			                                "stylers": [
			                                    {
			                                        "color": "#dadada"
			                                    }
			                                ]
			                            },
			                            {
			                                "featureType": "road.highway",
			                                "elementType": "labels.text.fill",
			                                "stylers": [
			                                    {
			                                        "color": "#616161"
			                                    }
			                                ]
			                            },
			                            {
			                                "featureType": "road.local",
			                                "elementType": "labels.text.fill",
			                                "stylers": [
			                                    {
			                                        "color": "#9e9e9e"
			                                    }
			                                ]
			                            },
			                            {
			                                "featureType": "transit.line",
			                                "elementType": "geometry",
			                                "stylers": [
			                                    {
			                                        "color": "#e5e5e5"
			                                    }
			                                ]
			                            },
			                            {
			                                "featureType": "transit.station",
			                                "elementType": "geometry",
			                                "stylers": [
			                                    {
			                                        "color": "#eeeeee"
			                                    }
			                                ]
			                            },
			                            {
			                                "featureType": "water",
			                                "elementType": "geometry",
			                                "stylers": [
			                                    {
			                                        "color": "#c9c9c9"
			                                    }
			                                ]
			                            },
			                            {
			                                "featureType": "water",
			                                "elementType": "labels.text.fill",
			                                "stylers": [
			                                    {
			                                        "color": "#9e9e9e"
			                                    }
			                                ]
			                            }
			                        ]
			                    });

			                    var marker = new google.maps.Marker({
			                        position: myLatLng,
			                        map: map,
			                        title: "' . esc_attr( $map_title ) . '",
			                        icon:("' . esc_url( $map_icon ) . '"),
			                    });
			                }
						' );
					$output .= '<div class="gt-page-banner--inner">';
						$output .= '<div class="container">';
							$output .= '<div class="gt-box text-center">';
								if( !empty( $top_text ) ) {
									$output .= '<div class="gt-box--subtitle">' . esc_attr( $top_text ) . '</div>';
								}

								if( !empty( $title ) ) {
									$output .= '<div class="gt-box--title">';
										$output .= '<h1>' . esc_attr( $title ) . '</h1>';
									$output .= '</div>';
								}

								if( !empty( $bottom_text ) ) {
									$output .= '<div class="gt-box--description">' . esc_attr( $bottom_text ) . '</div>';
								}
							$output .= '</div>';
						$output .= '</div>';
					$output .= '</div>';
				$output .= '</section>';

		} else {

			$image_url = wp_get_attachment_image_src( esc_attr( $bg_id ), 'nucy-page-banner' );
			if( !empty( $image_url ) ) {
				$image_url = $image_url[0];
				$output .= '<section class="gt-page-banner" style="background-image:url(' . esc_url( $image_url ) . ');">';
			} else {
				$output .= '<section class="gt-page-banner">';
			}
				$output .= '<div class="gt-page-banner--inner">';
					$output .= '<div class="container">';
						$output .= '<div class="gt-box text-center">';
							if( !empty( $top_text ) ) {
								$output .= '<div class="gt-box--subtitle">' . esc_attr( $top_text ) . '</div>';
							}

							if( !empty( $title ) ) {
								$output .= '<div class="gt-box--title">';
									$output .= '<h1>' . esc_attr( $title ) . '</h1>';
								$output .= '</div>';
							} else {
								if( is_category() ) {
									$title = single_cat_title( '', false );
								} elseif( is_tag() ) {
									$title = single_tag_title( '', false );
								} elseif( is_search() ) {
									$title = get_search_query();
								} elseif( is_author() ) {
									$title = get_the_author();
								} elseif( is_home() ) {
									$title = esc_html__( 'Home', 'nucy' );
								} elseif( is_404() ) {
									$title = esc_html__( '404 Page', 'nucy' );
								} elseif( is_attachment() or is_page() or is_single() ) {
									$title = get_the_title();
								} elseif(  is_post_type_archive() ) {
									$title = post_type_archive_title( '', false );
								} elseif(  is_tax() ) {
									$title = single_term_title( '', false );
								} else {
									if ( is_day() ) {
										$title = sprintf( esc_html__( 'Daily Archives: %s', 'nucy' ), get_the_date() );
									} elseif ( is_month() ) {
										$title = sprintf( esc_html__( 'Monthly Archives: %s', 'nucy' ), get_the_date( _x( 'F Y', 'Monthly archives date format', 'nucy' ) ) );
									} elseif ( is_year() ) {
										$title = sprintf( esc_html__( 'Yearly Archives: %s', 'nucy' ), get_the_date( _x( 'Y', 'Yearly archives date format', 'nucy' ) ) );
									} else {
										$title = esc_html__( 'Archives', 'nucy' );
									}
								}
								$output .= '<div class="gt-box--title">';
									$output .= '<h1>' . esc_attr( $title ) . '</h1>';
								$output .= '</div>';
							}

							if( !empty( $bottom_text ) ) {
								$output .= '<div class="gt-box--description">' . esc_attr( $bottom_text ) . '</div>';
							}
						$output .= '</div>';
					$output .= '</div>';
				$output .= '</div>';
			$output .= '</section>';

		}

		return $output;
	}



	/*======
	*
	* Google Map
	*
	======*/
	function nucy_google_maps_create( $map_lat = "", $map_lng = "", $map_title = "" ) {
		if( !empty( $map_lat ) and !empty( $map_lng ) and !empty( $map_title ) ) {
			$output = "";
			$output .= '<div id="map-element"></div>';
			$map_icon = get_template_directory_uri() . '/include/assets/img/mapicon.svg';
			$output .= '<script>
	            function initMap() {
	                var myLatLng = {lat: ' . esc_attr( $map_lat ) . ', lng: ' . esc_attr( $map_lng ) . '};

	                var map = new google.maps.Map(document.getElementById("map"), {
	                    zoom: 12,
	                    center: myLatLng,
	                    scrollwheel: false,
	                    panControl: false,
	                    styles: [
	                        {
	                            "elementType": "geometry",
	                            "stylers": [
	                                {
	                                    "color": "#f5f5f5"
	                                }
	                            ]
	                        },
	                        {
	                            "elementType": "labels.icon",
	                            "stylers": [
	                                {
	                                    "visibility": "off"
	                                }
	                            ]
	                        },
	                        {
	                            "elementType": "labels.text.fill",
	                            "stylers": [
	                                {
	                                    "color": "#616161"
	                                }
	                            ]
	                        },
	                        {
	                            "elementType": "labels.text.stroke",
	                            "stylers": [
	                                {
	                                    "color": "#f5f5f5"
	                                }
	                            ]
	                        },
	                        {
	                            "featureType": "administrative.land_parcel",
	                            "elementType": "labels.text.fill",
	                            "stylers": [
	                                {
	                                    "color": "#bdbdbd"
	                                }
	                            ]
	                        },
	                        {
	                            "featureType": "poi",
	                            "elementType": "geometry",
	                            "stylers": [
	                                {
	                                    "color": "#eeeeee"
	                                }
	                            ]
	                        },
	                        {
	                            "featureType": "poi",
	                            "elementType": "labels.text.fill",
	                            "stylers": [
	                                {
	                                    "color": "#757575"
	                                }
	                            ]
	                        },
	                        {
	                            "featureType": "poi.park",
	                            "elementType": "geometry",
	                            "stylers": [
	                                {
	                                    "color": "#e5e5e5"
	                                }
	                            ]
	                        },
	                        {
	                            "featureType": "poi.park",
	                            "elementType": "labels.text.fill",
	                            "stylers": [
	                                {
	                                    "color": "#9e9e9e"
	                                }
	                            ]
	                        },
	                        {
	                            "featureType": "road",
	                            "elementType": "geometry",
	                            "stylers": [
	                                {
	                                    "color": "#ffffff"
	                                }
	                            ]
	                        },
	                        {
	                            "featureType": "road.arterial",
	                            "elementType": "labels.text.fill",
	                            "stylers": [
	                                {
	                                    "color": "#757575"
	                                }
	                            ]
	                        },
	                        {
	                            "featureType": "road.highway",
	                            "elementType": "geometry",
	                            "stylers": [
	                                {
	                                    "color": "#dadada"
	                                }
	                            ]
	                        },
	                        {
	                            "featureType": "road.highway",
	                            "elementType": "labels.text.fill",
	                            "stylers": [
	                                {
	                                    "color": "#616161"
	                                }
	                            ]
	                        },
	                        {
	                            "featureType": "road.local",
	                            "elementType": "labels.text.fill",
	                            "stylers": [
	                                {
	                                    "color": "#9e9e9e"
	                                }
	                            ]
	                        },
	                        {
	                            "featureType": "transit.line",
	                            "elementType": "geometry",
	                            "stylers": [
	                                {
	                                    "color": "#e5e5e5"
	                                }
	                            ]
	                        },
	                        {
	                            "featureType": "transit.station",
	                            "elementType": "geometry",
	                            "stylers": [
	                                {
	                                    "color": "#eeeeee"
	                                }
	                            ]
	                        },
	                        {
	                            "featureType": "water",
	                            "elementType": "geometry",
	                            "stylers": [
	                                {
	                                    "color": "#c9c9c9"
	                                }
	                            ]
	                        },
	                        {
	                            "featureType": "water",
	                            "elementType": "labels.text.fill",
	                            "stylers": [
	                                {
	                                    "color": "#9e9e9e"
	                                }
	                            ]
	                        }
	                    ]
	                });

	                var marker = new google.maps.Marker({
	                    position: myLatLng,
	                    map: map-element,
	                    title: "' . esc_attr( $map_title ) . '",
	                    icon:("' . esc_url( $map_icon ) . '"),
	                });
	            }</script>
			';
			return $output;
		}
	}



	/*======
	*
	* Woo Product List Styles
	*
	======*/
	function nucy_woo_product_style_1( $product = "", $price = "", $excerpt = "", $read_more = "", $category = "" ) {
		$output = "";
		if ( function_exists( 'is_woocommerce' ) ) {
			$output .= '<div class="gt-shop-item-box">';
				$output .= '<div class="gt-box">';
					if ( has_post_thumbnail( $product ) ) {
						$image_url = wp_get_attachment_image_src( get_post_thumbnail_id( $product ), 'nucy-shop-1' );
						if( !empty( $image_url ) ) {
							$output .= '<div class="gt-box--image">';
								$output .= '<a href="' . get_the_permalink( $product ) . '" title="' . the_title_attribute( array( 'echo' => 0, 'post' => $product ) ) . '">';
									$output .= '<img src="' . esc_url( $image_url[0] ) . '" alt="' . the_title_attribute( array( 'echo' => 0, 'post' => $product ) ) . '" />';
								$output .= '</a>';
							$output .= '</div>';
						}
					}

					if( $category == 'true' ) {
						$product_cats = wp_get_post_terms( get_the_ID(), 'product_cat' );
						foreach( $product_cats as $cat ) {
							$output .= '<div class="gt-box--label">';
								if( !empty( $cat ) ) {
									$output .= '<span>';
										$output .= esc_attr( $cat->name );
									$output .= '</span>';
								}
							$output .= '</div>';
						}
					}

					$output .= '<div class="gt-box--content">';
						$output .= '<div class="gt-box--title">';
							$output .= '<h3><a href="' . get_the_permalink( $product ) . '" title="' . the_title_attribute( array( 'echo' => 0, 'post' => $product ) ) . '">' . get_the_title( $product ) . '</a></h3>';
						$output .= '</div>';

						if( $excerpt == 'true' ) {
							$summary = get_the_excerpt();
							if( !empty( $summary ) ) {
								$output .= '<div class="gt-box--info">' . get_the_excerpt() . '</div>';
							}
						}

						if( $price == 'true' ) {
							$product = wc_get_product( get_the_ID() );
							if( !empty( $product ) ) {
								$price = $product->get_price_html();
								if( !empty( $price ) ) {
									$output .= '<div class="gt-box--price">' . $product->get_price_html() . '</div>';
								}
							}
						}

						if( $read_more == 'true' ) {
							$output .= '<a href="' . get_the_permalink( $product ) . '" class="btn gt-btn-style-3" title="' . esc_attr__( 'Add to Cart', 'nucy' ) . '">' . esc_html__( 'Add to Cart', 'nucy' ) . '</a>';
						}
					$output .= '</div>';
				$output .= '</div>';
			$output .= '</div>';
		}
		return $output;
	}



	/*======
	*
	* Portfolio Styles
	*
	======*/
	function nucy_portfolio_style_1( $post = "", $image = "", $excerpt = "", $category = "", $read_more = "" ) {
		$output = "";
		if( !empty( $post ) ) {
			$output .= '<div class="gt-portfolio-box text-center">';
				$output .= '<div class="gt-box">';
					$output .= '<div class="gt-box--image">';
						if( $image == "true" ) {
							if ( has_post_thumbnail( $post ) ) {
								$image_url = wp_get_attachment_image_src( get_post_thumbnail_id( $post ), 'nucy-portfolio-1' );
								if( !empty( $image_url ) ) {
									$output .= '<a href="' . get_the_permalink( $post ) . '" title="' . the_title_attribute( array( 'echo' => 0, 'post' => $post ) ) . '">';
										$output .= '<img src="' . esc_url( $image_url[0] ) . '" alt="' . the_title_attribute( array( 'echo' => 0, 'post' => $post ) ) . '" />';
									$output .= '</a>';
								}
							}
						}
					$output .= '</div>';

					$output .= '<div class="gt-box--content">';
						if( $category == "true" ) {
							$categories = wp_get_post_terms( $post, 'portfolio-category' );
							if( !empty( $categories ) ) {
								$output .= '<div class="gt-box--cat">';
									$output .= '<ul>';
										foreach( $categories as $cat ) {
											if( !empty( $cat ) ) {
												$output .= '<li>';
													$output .= '<a href="' . get_term_link( $cat->term_id ) . '" title="' . esc_attr( $cat->name ) . '">' . esc_attr( $cat->name ) . '</a>';
												$output .= '</li>';
											}
										}
									$output .= '</ul>';
								$output .= '</div>';
							}
						}

						$output .= '<div class="gt-box--title">';
							$output .= '<a href="' . get_the_permalink( $post ) . '" title="' . the_title_attribute( array( 'echo' => 0, 'post' => $post ) ) . '">' . get_the_title( $post ) . '</a>';
						$output .= '</div>';

						$output .= '<div class="gt-box--details">';
							if( $excerpt == 'true' ) {
								$summary = get_the_excerpt();
								if( !empty( $summary ) ) {
									$output .= '<p>' . get_the_excerpt() . '</p>';
								}
							}

							if( $read_more == 'true' ) {
								$output .= nucy_read_more_button( $post = get_the_ID(), $style = 'gt-btn-style-7' );
							}
						$output .= '</div>';
					$output .= '</div>';
				$output .= '</div>';
			$output .= '</div>';
		}
		return $output;
	}



	function nucy_portfolio_style_2( $post = "", $excerpt = "", $category = "", $read_more = "" ) {
		$output = "";
		if( !empty( $post ) ) {
			$output .= '<div class="gt-portfolio-box style-2 text-center">';
				if ( has_post_thumbnail( $post ) ) {
					$image_url = wp_get_attachment_image_src( get_post_thumbnail_id( $post ), 'nucy-portfolio-1' );
					if( !empty( $image_url ) ) {
						$image_url = $image_url[0];
					} else {
						$image_url = "";
					}
				} else {
					$image_url = "";
				}

				$output .= '<div class="gt-box" style="background-image: url(' . esc_url( $image_url ) . ');">';
					$output .= '<div class="gt-box--content">';
						if( $category == "true" ) {
							$categories = wp_get_post_terms( $post, 'portfolio-category' );
							if( !empty( $categories ) ) {
								$output .= '<div class="gt-box--cat">';
									$output .= '<ul>';
										foreach( $categories as $cat ) {
											if( !empty( $cat ) ) {
												$output .= '<li>';
													$output .= '<a href="' . get_term_link( $cat->term_id ) . '" title="' . esc_attr( $cat->name ) . '">' . esc_attr( $cat->name ) . '</a>';
												$output .= '</li>';
											}
										}
									$output .= '</ul>';
								$output .= '</div>';
							}
						}

						$output .= '<div class="gt-box--title">';
							$output .= '<a href="' . get_the_permalink( $post ) . '" title="' . the_title_attribute( array( 'echo' => 0, 'post' => $post ) ) . '">' . get_the_title( $post ) . '</a>';
						$output .= '</div>';

						$output .= '<div class="gt-box--details">';
							if( $excerpt == 'true' ) {
								$summary = get_the_excerpt();
								if( !empty( $summary ) ) {
									$output .= '<p>' . get_the_excerpt() . '</p>';
								}
							}

							if( $read_more == 'true' ) {
								$output .= nucy_read_more_button( $post = get_the_ID(), $style = 'gt-btn-style-7' );
							}
						$output .= '</div>';
					$output .= '</div>';
				$output .= '</div>';
			$output .= '</div>';
		}
		return $output;
	}



	/*======
	*
	* Post List Styles
	*
	======*/
	function nucy_post_style_1( $post = "", $image = "", $excerpt = "", $read_more = "", $category = "", $date = "" ) {
		$output = "";
		if( !empty( $post ) ) {
			if ( is_sticky( $post ) ) {
				$output .= '<div class="gt-box sticky-post">';
			} else {
				$output .= '<div class="gt-box">';
			}

				$output .= '<div class="gt-box--title">';
					$output .= '<h2><a href="' . get_the_permalink( $post ) . '" title="' . the_title_attribute( array( 'echo' => 0, 'post' => $post ) ) . '">' . get_the_title( $post ) . '</a></h2>';
				$output .= '</div>';

				if( $date == "true" or $category == "true" ) {
					$output .= '<div class="gt-box--details">';
						if( $date == "true" ) {
							$output .= '<span>';
								$output .= get_the_time( get_option( 'date_format' ), $post );
							$output .= '</span>';
						}

						if( !empty( get_the_category_list( ", ", '', $post ) ) ) {
							if( $date == "true" or $category == "true" ) {
								$output .= ' ' . esc_html__( 'in', 'nucy' ) . ' ';
							}
						}

						if( $category == "true" ) {
							if ( !empty( get_the_category_list( ", ", '', $post ) ) ) {
								$output .= '<span>';
									$output .= get_the_category_list( ", ", '', $post );
								$output .= '</span>';
							}
						}
					$output .= '</div>';
				}

				if( $image == "true" ) {
					if ( has_post_thumbnail( $post ) ) {
						$image_url = wp_get_attachment_image_src( get_post_thumbnail_id( $post ), 'nucy-post-1' );
						if( !empty( $image_url ) ) {
							$output .= '<div class="gt-box--images">';
								$output .= '<a href="' . get_the_permalink( $post ) . '" title="' . the_title_attribute( array( 'echo' => 0, 'post' => $post ) ) . '">';
									$output .= '<img src="' . esc_url( $image_url[0] ) . '" alt="' . the_title_attribute( array( 'echo' => 0, 'post' => $post ) ) . '" />';
								$output .= '</a>';
							$output .= '</div>';
						}
					}
				}

				if( $excerpt == 'true' ) {
					$summary = get_the_excerpt();
					if( !empty( $summary ) ) {
						$output .= '<div class="gt-box--summary">' . get_the_excerpt() . '</div>';
					}
				}

				if( $read_more == 'true' ) {
					$output .= nucy_read_more_button( $post = get_the_ID(), $style = 'gt-btn-style-1' );
				}

			$output .= '</div>';
		}
		return $output;
	}



	function nucy_post_style_2( $post = "", $read_more = "", $date = "" ) {
		$output = "";
		if( !empty( $post ) ) {
			if ( is_sticky( $post ) ) {
				$output .= '<div class="gt-box sticky-post">';
			} else {
				$output .= '<div class="gt-box">';
			}

				if( $date == "true" ) {
					$output .= '<div class="gt-box--date">';
						$output .= get_the_time( get_option( 'date_format' ), $post );
					$output .= '</div>';
				}

				$output .= '<div class="gt-box--title">';
					$output .= '<h2><a href="' . get_the_permalink( $post ) . '" title="' . the_title_attribute( array( 'echo' => 0, 'post' => $post ) ) . '">' . get_the_title( $post ) . '</a></h2>';
				$output .= '</div>';

				if( $read_more == 'true' ) {
					$output .= '<div class="gt-box--link">';
						$output .= nucy_read_more_button( $post = get_the_ID(), $style = 'gt-btn-style-1' );
					$output .= '</div>';
				}

			$output .= '</div>';
		}
		return $output;
	}



	function nucy_post_style_3( $post = "", $image = "", $read_more = "", $category = "", $date = "" ) {
		$output = "";
		if( !empty( $post ) ) {
			$output .= '<div class="gt-news-box">';
				if ( is_sticky( $post ) ) {
					$output .= '<div class="gt-box sticky-post">';
				} else {
					$output .= '<div class="gt-box">';
				}

					if( $image == "true" ) {
						if ( has_post_thumbnail( $post ) ) {
							$image_url = wp_get_attachment_image_src( get_post_thumbnail_id( $post ), 'nucy-post-1' );
							if( !empty( $image_url ) ) {
								$output .= '<div class="gt-box--image">';
									$output .= '<a href="' . get_the_permalink( $post ) . '" title="' . the_title_attribute( array( 'echo' => 0, 'post' => $post ) ) . '">';
										$output .= '<img src="' . esc_url( $image_url[0] ) . '" alt="' . the_title_attribute( array( 'echo' => 0, 'post' => $post ) ) . '" />';
									$output .= '</a>';
								$output .= '</div>';
							}
						}
					}

					$output .= '<div class="gt-box--content">';
						$output .= '<div class="gt-inner">';
							if( $image == "true" ) {
								if ( has_post_thumbnail( $post ) ) {
									if( $category == "true" ) {
										if ( !empty( get_the_category_list( ", ", '', $post ) ) ) {
											$output .= '<div class="gt-box--cat">';
												$output .= get_the_category_list( ", ", '', $post );
											$output .= '</div>';
										}
									}
								}
							}

							if( $date == "true" ) {
								$output .= '<div class="gt-box--date">';
									$output .= '<i class="far fa-calendar"></i>';
									$output .= get_the_time( get_option( 'date_format' ), $post );
								$output .= '</div>';
							}

							$output .= '<div class="gt-box--title">';
								$output .= '<h2><a href="' . get_the_permalink( $post ) . '" title="' . the_title_attribute( array( 'echo' => 0, 'post' => $post ) ) . '">' . get_the_title( $post ) . '</a></h2>';
							$output .= '</div>';

							if( $read_more == 'true' ) {
								$output .= nucy_read_more_button( $post = get_the_ID(), $style = 'gt-btn-style-5' );
							}
						$output .= '</div>';
					$output .= '</div>';

				$output .= '</div>';
			$output .= '</div>';
		}
		return $output;
	}



	/*======
	*
	* Post Listing
	*
	======*/
	function nucy_post_listing() {
		function nucy_post_list_style_1() {
			echo '<div class="gt-blog-list-simple">';
				while ( have_posts() ) : the_post();
					echo nucy_post_style_1( $post = get_the_ID(), $image = "true", $excerpt = "true", $read_more = "true", $category = "true", $date = "true" );
				endwhile;
			echo '</div>';
		}

		function nucy_post_list_style_2() {
			echo '<div class="gt-blog-list-minimal">';
				while ( have_posts() ) : the_post();
					echo nucy_post_style_2( $post = get_the_ID(), $image = "true", $excerpt = "true", $detail = "true", $read_more = "true" );
				endwhile;
			echo '</div>';
		}

		function nucy_post_list_style_3() {
			echo '<div class="gt-news-box">';
				echo '<div class="row">';
					while ( have_posts() ) : the_post();
						echo '<div class="col-lg-4">';
							echo nucy_post_style_3( $post = get_the_ID(), $image = "true", $read_more = "true", $category = "true", $date = "true" );
						echo '</div>';
					endwhile;
				echo '</div>';
			echo '</div>';
		}

		if( is_category() ) {
			$list_style = get_theme_mod( 'nucy_archives_categories_post_style', 'style-1' );
		} elseif( is_tag() ) {
			$list_style = get_theme_mod( 'nucy_archives_tags_post_style', 'style-1' );
		} elseif( is_search() ) {
			$list_style = get_theme_mod( 'nucy_archives_searches_post_style', 'style-1' );
		} elseif( is_author() ) {
			$list_style = get_theme_mod( 'nucy_archives_authors_post_style', 'style-1' );
		} else {
			$list_style = get_theme_mod( 'nucy_archives_archives_post_style', 'style-1' );
		}

		if( $list_style == "style-2" ) {
			nucy_post_list_style_2();
		} elseif( $list_style == "style-3" ) {
			nucy_post_list_style_3();
		} else {
			nucy_post_list_style_1();
		}
	}



	/*======
	*
	* Read More Button
	*
	======*/
	function nucy_read_more_button( $post = "", $style = "" ) {
		if( !empty( $post ) ) {
			if( !empty( $style ) ) {
				$style = esc_attr( $style );
			} else {
				$style = "gt-btn-style-1";
			}

			$output = '<a href="' . get_the_permalink( $post ) . '" class="btn ' . esc_attr( $style ) . '" title="' . esc_attr__( 'Read More', 'nucy' ) . '">' . esc_html__( 'Read More', 'nucy' ) . '</a>';
			return $output;
		}
	}



	/*======
	*
	* Pagination for Archive
	*
	======*/
	function nucy_pagination() {
		if( is_singular() )
			return;

		global $wp_query;

		if( $wp_query->max_num_pages <= 1 )
			return;

		$paged = get_query_var( 'paged' ) ? absint( get_query_var( 'paged' ) ) : 1;
		$max   = intval( $wp_query->max_num_pages );

		if( $paged >= 1 )
			$links[] = $paged;

		if( $paged >= 3 ) {
			$links[] = $paged - 1;
			$links[] = $paged - 2;
		}

		if( ( $paged + 2 ) <= $max ) {
			$links[] = $paged + 2;
			$links[] = $paged + 1;
		}

		$prev = '<span>' . esc_html__( 'Previous', 'nucy' ) . '</span>';
		$next = '<span>' . esc_html__( 'Next', 'nucy' ) . '</span>';

		echo '<div class="gt-pagination">';
			echo '<nav>';
				echo '<ul class="pagination justify-content-center">';

					if( get_previous_posts_link() )
						printf( '<li class="page-item previous">' . get_previous_posts_link( $prev ) . '</li>' );

					?>
						<li class="page-item total-pages"><span><?php esc_html_e( 'Page', 'nucy' ) . ' ' . $paged . ' ' . esc_html__( 'of', 'nucy' ) . ' ' . $max; ?></span></li>
					<?php
					if( get_next_posts_link() )
						printf( '<li class="page-item next">' . get_next_posts_link( $next ) . '</li>' );

				echo '</ul>';
			echo '</nav>';
		echo '</div>';
	}



	/*======
	*
	* Pagination for Elements
	*
	======*/
	function nucy_element_pagination( $paged = "", $query = "" ) {
		if( !empty( $paged ) or !empty( $query ) ) {
			if( !empty( $style ) ) {
				$style = esc_attr( $style );
			} else {
				$style = "style-1";
			}

			$output = "";
			$prev = '<span>' . esc_html__( 'Previous', 'nucy' ) . '</span>';
			$next = '<span>' . esc_html__( 'Next', 'nucy' ) . '</span>';	
			$prev_link = get_previous_posts_link( $prev );
			$next_link = get_next_posts_link( $next, $query->max_num_pages );

			if( !empty( $prev_link ) or !empty( $next_link ) ) {
				$output .= '<div class="gt-pagination">';
					$output .= '<nav>';
						$output .= '<ul class="pagination justify-content-center">';
							$prev_link = get_previous_posts_link( $prev );
							if( !empty( $prev_link ) ) {
								$output .= '<li class="page-item previous">' . get_previous_posts_link( $prev ) . '</li>';
							}

							$next_link = get_next_posts_link( $next, $query->max_num_pages );
							if( !empty( $next_link ) ) {
								$output .= '<li class="page-item next">' . get_next_posts_link( $next, $query->max_num_pages ) . '</li>';
							}
						$output.= '</ul>';
					$output .= '</nav>';
				$output .= '</div>';
			}

			return $output;
		}
	}



	/*======
	*
	* Elements of Post Singles
	*
	======*/
		/*====== Featured Content ======*/
		function nucy_featured_content( $post = "" ) {
			$output = "";

			if ( function_exists( 'rwmb_meta' ) ) {
				$hide_featured_content = rwmb_meta( 'hide-featured-content' );
				$audio_content = rwmb_meta( 'audio-html' );
				$video_embed = rwmb_meta( 'video-embed' );
				$embed =  isset( $video['video-embed'] ) ? $video['video-embed'] : '';
				$gallery_type = rwmb_meta( 'image-gallery-type' );
				$image_gallery = rwmb_meta( 'image-gallery', array( 'size' => 'thumbnail' ) );

				if( !$hide_featured_content == '1' ) {
					if ( has_post_format( 'video' ) ) {
						if( !empty( $video_embed ) ) {
							$output .= '<div class="fgt-single-featured">';
								$output .= $video_embed;
							$output .= '</div>';
						}
					} elseif ( has_post_format( 'audio' ) ) {
						if( !empty( $audio_content ) ) {
							$output .= '<div class="gt-single-featured">';
								$output .= rwmb_meta( 'audio-html' );
							$output .= '</div>';
						}
					} elseif( has_post_format( 'gallery' ) ) {
						if( !empty( $image_gallery ) ) {
							$output .= '<div class="gt-single-featured">';
								$output .= '<div class="swiper-container gt-main-slider" data-gt-speed="600" data-gt-parallax="true" data-gt-direction="horizontal" data-gt-item="1" data-gt-item-space="0">';
									$output .= '<div class="swiper-wrapper">';
										foreach ( $image_gallery as $image ) {
											if( !empty( $image ) ) {
												$image_src = wp_get_attachment_image_src( esc_attr( $image["ID"] ), 'nucy-post-1' );
												if( !empty( $image_src ) ) {
													$output .= '<div class="swiper-slide">';
														$output .= '<img data-lazy="' . esc_url( $image_src[0] ) . '" width="' . esc_attr( $image_src[1] ) . '" height="' . esc_attr( $image_src[2] ) . '">';
													$output .= '</div>';
												}								
											}
										}
									$output .= '</div>';
								$output .= '</div>';
							$output .= '</div>';
						}
					} else {
						if( is_singular( 'post' ) ) {
							$post_image = get_theme_mod( 'nucy_posts_image', '1' );
							if ( $post_image == '1' ) {
								if ( has_post_thumbnail() ) {
									$output .= '<div class="gt-single-featured">';
										$output .= get_the_post_thumbnail( $post, 'nucy-post-1' );
									$output .= '</div>';
								}
							}
						} else {
							if ( has_post_thumbnail() ) {
								$output .= '<div class="gt-single-featured">';
									$output .= get_the_post_thumbnail( $post, 'nucy-post-1' );
								$output .= '</div>';
							}
						}
					}
				}
			} else {
				if( is_singular( 'post' ) ) {
					$post_image = get_theme_mod( 'nucy_posts_image', '1' );
					if ( $post_image == '1' ) {
						if ( has_post_thumbnail() ) {
							$output .= '<div class="gt-single-featured">';
								$output .= get_the_post_thumbnail( $post, 'nucy-post-1' );
							$output .= '</div>';
						}
					}
				} else {
					if ( has_post_thumbnail() ) {
						$output .= '<div class="gt-single-featured">';
							$output .= get_the_post_thumbnail( $post, 'nucy-post-1' );
						$output .= '</div>';
					}
				}
			}

			return $output;
		}



		/*====== Post Details ======*/
		function nucy_post_details( $post = "", $author = "", $comment = "", $category = "", $date = "", $style = "" ) {
			if( !empty( $post ) ) {
				if( !empty( $style ) ) {
					$style = esc_attr( $style );
				} else {
					$style = "style-1";
				}

				if( $author == "true" or $category == "true" or $date == "true" ) {
					$output = '';
					$output .= '<div class="post-details ' . esc_attr( $style ) . '">';
						$output .= '<ul>';
							if( $author == "true" ) {
								$get_the_author = get_the_author();
								$get_the_author_id = get_user_by( 'ID', $get_the_author );
								$output .= $get_the_author_id;
								$author_avatar = get_avatar( get_the_author_meta( 'user_email', $get_the_author_id ), apply_filters( 'wpex_author_bio_avatar_size', 120 ) );
								$display_name = get_the_author_meta( 'display_name', $get_the_author_id );
								if( !empty( $display_name ) ) {
									$output .= '<li class="author">';
										$output .= '<a href="' . get_author_posts_url( get_the_author_meta( 'ID', $get_the_author_id ) ) . '">';
											if( !empty( $author_avatar ) ) {
												$output .= get_avatar( get_the_author_meta( 'user_email', $get_the_author_id ), apply_filters( 'thumbnail', 20 ) );
											}
											if( !empty( $display_name ) ) {
												$output .= '<span>' . get_the_author_meta( 'display_name', $get_the_author_id ) . '</span>';
											}
										$output .= '</a>';
									$output .= '</li>';
								}
							}
							if( $comment == "true" ) {
								if ( comments_open() ) {
									$output .= '<li class="comment">';
										$output .= '<i class="fas fa-comments" aria-hidden="true"></i>';
										$num_comments = get_comments_number( $post );
										if ( $num_comments == 0 ) {
											$comments = esc_html__( '0 Comment', 'nucy' );
										} elseif ( $num_comments > 1 ) {
											$comments = $num_comments . ' ' . esc_html__( 'Comments', 'nucy' );
										} else {
											$comments = esc_html__( '1 Comment', 'nucy' );
										}
										$output .= $comments;
									$output .= '</li>';
								}
							}
							if( $category == "true" ) {
								if ( !empty( get_the_category_list( ", ", '', $post ) ) ) {
									$output .= '<li class="category">';
										$output .= '<i class="fas fa-folder-open" aria-hidden="true"></i>';
										$output .= get_the_category_list( ", ", '', $post );
									$output .= '</li>';
								}
							}
							if( $date == "true" ) {
								$output .= '<li class="date">';
									$output .= '<i class="far fa-clock" aria-hidden="true"></i>';
									$output .= get_the_time( get_option( 'date_format' ), $post );
								$output .= '</li>';
							}
						$output .= '</ul>';
					$output .= '</div>';
					return $output;
				}
			}
		}



		/*====== Author Box ======*/
		function nucy_post_author() {
			$author = get_the_author();
			$author_display_name = get_the_author_meta( 'display_name' );
			$author_description = get_the_author_meta( 'description' );
			$author_url = get_the_author_meta( 'user_url' );
			$author_posts_url = esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) );
			$author_avatar = get_avatar( get_the_author_meta( 'user_email' ), apply_filters( 'wpex_author_bio_avatar_size', 110 ) );

			if ( !empty( $author_description ) ) {
					$output .= '<div class="gt-post-author">';
					$output .= '<div class="gt-inner">';
						if ( !empty( $author_avatar ) ) {
							$output .= '<div class="image">';
								$output .= '<a href="' . esc_url( $author_posts_url ). '" rel="author">';
									$output .= get_avatar( get_the_author_meta( 'user_email' ), apply_filters( 'wpex_author_bio_avatar_size', 70 ) );
								$output .= '</a>';
							$output .= '</div>';
						}
						if ( !empty( $author_description ) or !empty( $author_display_name ) ) {
							$output .= '<div class="content">';
								if ( !empty( $author_display_name ) ) {
									$output .= '<div class="h5">' . esc_attr( $author_display_name ) . '</div>';
								}

								if ( !empty( $author_description ) ) {
									$output .= '<p>' . get_the_author_meta( 'description', get_the_author_meta( 'ID' ) ) . '</p>';
								}

								if( function_exists( 'nucy_user_social_links' ) ) {
									$output .= nucy_user_social_links( $user_id = get_the_author_meta( 'ID' ) );
								}
							$output .= '</div>';
						}
					$output .= '</div>';
				$output .= '</div>';
				return $output;
			}
		}



		/*====== Post Navigation ======*/
		function nucy_post_navigation() {
			$prev_text = esc_html__( 'Previous', 'nucy' );
			$next_text = esc_html__( 'Next', 'nucy' );
			$prev_post = get_previous_post( false );
			$next_post = get_next_post( false );

			if( !empty( $prev_post ) or !empty( $next_post ) ) {
				$output = '<div class="gt-page-l-nav">';
					if( !empty( $prev_post ) ) {
						$output .= '<a href="' . get_permalink( $prev_post->ID ) . '" title="' . esc_attr( $prev_post->post_title ) . '">' . $prev_text . '</a>';
					}
					if( !empty( $next_post ) ) {
						$output .= '<a href="' . get_permalink( $next_post->ID ) . '" title="' . esc_attr( $next_post->post_title ) . '">' . $next_text . '</a>';
					}
				$output .= '</div>';
				return $output;
			}
		}



		/*====== Related Posts ======*/
		function nucy_related_posts( $post = "" ) {
			$output = "";
			$tags = wp_get_post_tags( $post );
			$count = get_theme_mod( 'nucy_posts_related_count', '2' );
			if ( !empty( $tags ) ) {
				$tag_ids = array();
				foreach( $tags as $individual_tag ) {
					$tag_ids[] = $individual_tag->term_id;
				}

				if( !empty( $tag_ids ) ) {
					$args = array(
						'tag__in' => $tag_ids,
						'post__not_in' => array( $post ),
						'post_status' => 'publish',
						'post_type' => 'post',
						'ignore_sticky_posts' => true,
						'posts_per_page' => $count
					);
					$wp_query = new wp_query( $args );
					if ( $wp_query->have_posts() ) {
						$output .= '<div class="gt-related-posts">';
							$output .= '<div class="gt-bottom-space">';
								$output .= nucy_heading( $title = esc_html__( 'Related News', 'nucy' ), $top_title = esc_html__( 'You can find related news and posts.', 'nucy' ), $text = "", $align = "center" );
							$output .= '</div>';
							$output .= '<div class="row justify-content-center">';
								while( $wp_query->have_posts() ) {
									$wp_query->the_post();
									$output .= '<div class="col-lg-4">';
										$output .= nucy_post_style_3( $post = get_the_ID(), $image = "true", $read_more = "true", $category = "true", $date = "true" );
									$output .= '</div>';
								}
							$output .= '</div>';
						$output .= '</div>';
						return $output;
					}
					wp_reset_postdata();
				}
			}
		}