<?php
/*======
*
* Font URLs
*
======*/
	function nucy_fonts_url() {
		$custom_font_list = array();

		/*====== Customize Variables ======*/
		$latin_extended = get_theme_mod( 'nucy_typography_latin_extended' );
		$cyrillic_extended = get_theme_mod( 'nucy_typography_cyrillic_extended' );
		$greek_extended = get_theme_mod( 'nucy_typography_greek_extended' );
		$font_weights = get_theme_mod( 'nucy_font_weights' );

		/*====== Weights ======*/
		if( !empty( $font_weights ) ) {
			$weights = ':' . $font_weights;
		} else {
			$weights = ":100,100italic,200,200italic,300,300italic,400,400italic,500,500italic,600,600italic,700,700italic,800,800italic,900,900italic";			
		}

		/*====== Theme Fonts ======*/
		$main_font = get_theme_mod( 'nucy_typography_main_font' );

		if( !empty( $main_font ) ) {
			$custom_font_list[] = $main_font;
		} else {
			$custom_font_list[] = "Montserrat";
		}

		if( !empty( $custom_font_list ) ) {
			$custom_font_list = array_unique( $custom_font_list );
			$prefixed_array = preg_filter( '/$/', $weights, $custom_font_list );
			if( !empty( $prefixed_array ) ) {
				$prefixed_imp = implode( '|', $prefixed_array );
				$font_names = rtrim( $prefixed_imp, '|' );				
			}
		}

		/*====== Subsets ======*/
		$subsets = array( "latin" );
		if( !empty( $latin_extended ) or $latin_extended == "1" ) {
			$subsets[] = "latin-ext";
		}

		if( !empty( $cyrillic_extended ) or $cyrillic_extended == "1" ) {
			$subsets[] = "cyrillic";
			$subsets[] = "cyrillic-ext";
		}

		if( !empty( $greek_extended ) or $greek_extended == "1" ) {
			$subsets[] = "greek";
			$subsets[] = "greek-ext";
		}

		if( !empty( $subsets ) ) {
			$subset_list = rtrim( implode( ',', $subsets ), ',' );
		}

		/*====== Font URL ======*/
		$font_url = '';
		$font_url = add_query_arg( 'family', urlencode( $font_names . '&subset=' . $subset_list . '' ), "//fonts.googleapis.com/css" );

		return $font_url;
	}

	function nucy_fonts_scripts() {
		wp_enqueue_style( 'nucy-fonts', nucy_fonts_url(), array(), '1.0.0' );
	}
	add_action( 'wp_enqueue_scripts', 'nucy_fonts_scripts' );



/*======
*
* Typography Selector
*
======*/
	function nucy_font_selector( $class = "", $family = "", $default = "" ) {
		if( !empty( $class ) and !empty( $family ) or  !empty( $default ) ) {
			if( !empty( $family ) and !empty( get_theme_mod( $family ) ) ) {
				$setting = get_theme_mod( $family );
			} else {
				$setting = $default;
			}

			if( $setting ) {
				$custom_style = $class . "{ font-family: '" . $setting . "'; }";
				return $custom_style;
			}
		}
	}

	function nucy_custom_fonts() {
		wp_enqueue_style( 'nucy-custom', get_template_directory_uri() . '/include/assets/css/custom.css', array(), '1.0.0' );
		wp_add_inline_style( 'nucy-custom', nucy_font_selector( 'body', 'nucy_typography_main_font', 'Montserrat' ) );
	}
	add_action( 'wp_enqueue_scripts', 'nucy_custom_fonts' );



/*======
*
* Custom Selector
*
======*/
	function nucy_custom_selector( $class = "", $property = "", $setting = "", $measurement = '', $important = '' ) {
		if( !empty( $class ) and !empty( $setting ) ) {
			if( get_theme_mod( $setting ) ) {
				if( $important == "true" ) {
					$custom_style = $class . '{ ' . $property . ': ' . get_theme_mod( $setting ) . $measurement . ' !important; }';
				} else {
					$custom_style = $class . '{ ' . $property . ': ' . get_theme_mod( $setting ) . $measurement . '; }';					
				}
				return $custom_style;
			}
		}
	}

	function nucy_custom_selectors() {
		wp_enqueue_style( 'nucy-custom', get_template_directory_uri() . '/include/assets/css/custom.css', array(), '1.0.0' );

		wp_add_inline_style( 'nucy-custom', nucy_custom_selector( '.gt-btn-style-1:hover, .gt-btn-style-2, .gt-btn-style-4:hover, .gt-btn-style-7:hover, button:hover, input[type="button"]:hover, input[type="submit"]:hover, input[type="reset"]:hover, .gt-newsletter form button, .gt-page-l-nav a:hover, .gt-single-page .post-tags ul li a:hover, .post-pages a:hover, .gt-pagination a.active, .gt-pagination .page-item a:focus, .gt-pagination .page-item a:hover, .woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt, .woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button, .woocommerce a.button, .woocommerce button.button.alt, .woocommerce input.button, .woocommerce a.button.alt, .woocommerce button.button:disabled, .woocommerce button.button:disabled[disabled], .woocommerce span.onsale, .woocommerce div.product .woocommerce-tabs ul.tabs li.active, .select2-container--default .select2-results__option--highlighted[aria-selected], .select2-container--default .select2-results__option--highlighted[data-selected]', 'background-color', 'nucy_theme_main_color' ) );

		wp_add_inline_style( 'nucy-custom', nucy_custom_selector( 'a:hover, a:focus, .gt-navbar .dropdown:hover > a, .gt-mobile-navbar .dropdown:hover > a, .gt-language-links li a.active, .gt-portfolio-box .gt-box--content a:hover, .woocommerce ul.products li.product .price, .woocommerce div.product p.price, .woocommerce-error::before, .woocommerce-info::before, .woocommerce-message::before, .woocommerce div.product p.price, .woocommerce div.product span.price', 'color', 'nucy_theme_main_color' ) );

		wp_add_inline_style( 'nucy-custom', nucy_custom_selector( '.gt-btn-style-4,.gt-btn-style-5:hover,.gt-btn-style-6', 'color', 'nucy_theme_main_color', '', 'true' ) );

		wp_add_inline_style( 'nucy-custom', nucy_custom_selector( '.gt-btn-style-1:hover, .gt-btn-style-2, .gt-btn-style-4, .gt-btn-style-4:hover, .gt-btn-style-7:hover, .gt-single-page .post-tags ul li a:hover, .post-pages a:hover, .woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt, .woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button, .woocommerce a.button, .woocommerce button.button.alt, .woocommerce input.button, .woocommerce a.button.alt, .woocommerce button.button:disabled, .woocommerce button.button:disabled[disabled]', 'border-color', 'nucy_theme_main_color' ) );

		wp_add_inline_style( 'nucy-custom', nucy_custom_selector( '.woocommerce-message, .woocommerce-error, .woocommerce-info, .woocommerce-message, .nucy-header .nucy-navbar.style-1 .navbar-menu li .dropdown-menu', 'border-top-color', 'nucy_theme_main_color' ) );

		wp_add_inline_style( 'nucy-custom', nucy_custom_selector( '.gt-footer .gt-footer--boxes .nav li a:before', 'border-left-color', 'nucy_theme_main_color' ) );





		wp_add_inline_style( 'nucy-custom', nucy_custom_selector( 'html', 'font-size', 'nucy_typography_html_font_size', 'px' ) );

		wp_add_inline_style( 'nucy-custom', nucy_custom_selector( 'body', 'font-size', 'nucy_typography_body_font_size', 'rem' ) );

		wp_add_inline_style( 'nucy-custom', nucy_custom_selector( 'h1', 'font-size', 'nucy_typography_h1_font_size', 'rem' ) );

		wp_add_inline_style( 'nucy-custom', nucy_custom_selector( 'h2', 'font-size', 'nucy_typography_h2_font_size', 'rem' ) );

		wp_add_inline_style( 'nucy-custom', nucy_custom_selector( 'h3', 'font-size', 'nucy_typography_h3_font_size', 'rem' ) );

		wp_add_inline_style( 'nucy-custom', nucy_custom_selector( 'h4', 'font-size', 'nucy_typography_h4_font_size', 'rem' ) );

		wp_add_inline_style( 'nucy-custom', nucy_custom_selector( 'h5', 'font-size', 'nucy_typography_h5_font_size', 'rem' ) );

		wp_add_inline_style( 'nucy-custom', nucy_custom_selector( 'h6', 'font-size', 'nucy_typography_h6_font_size', 'rem' ) );

		wp_add_inline_style( 'nucy-custom', nucy_custom_selector( '.upload-input, .select2-dropdown, .select2-search--dropdown .select2-search__field, .select2-container--default .select2-search--dropdown .select2-search__field, .select2-container--default .select2-selection--single, #add_payment_method table.cart td.actions .coupon .input-text, .woocommerce-cart table.cart td.actions .coupon .input-text, .woocommerce-checkout table.cart td.actions .coupon .input-text, #bbpress-forums #bbp-your-profile fieldset input, #bbpress-forums #bbp-your-profile fieldset textarea, .custom-file-control, input[type="email"], input[type="number"], input[type="password"], input[type="tel"], input[type="url"], input[type="text"], input[type="time"], input[type="week"], input[type="search"], input[type="month"], input[type="datetime"], input[type="date"], textarea, textarea.form-control, select, .woocommerce form .form-row .select2-container .select2-choice, .form-control, div.cs-select, .cs-select', 'font-size', 'nucy_typography_input_font_size', 'rem' ) );

		wp_add_inline_style( 'nucy-custom', nucy_custom_selector( '.custom-file-control::before, button, input[type="submit"], .woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt, .woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button', 'font-size', 'nucy_typography_button_font_size', 'rem' ) );
	}
	add_action( 'wp_enqueue_scripts', 'nucy_custom_selectors' );