<?php
/*======
*
* Customize Types
*
======*/
	/*====== Range Value ======*/
	if ( class_exists( 'WP_Customize_Control' ) ) {
		class Nucy_Customizer_Range_Value_Control extends WP_Customize_Control {
			public $type = 'range-value';
			public function render_content() {
				echo '<label>';
					echo '<span class="customize-control-title">' . esc_html( $this->label ) . '</span>';
					if ( !empty( $this->description ) ) {
						echo '<span class="description customize-control-description">' . $this->description . '</span>';
					}
					echo '<div class="range-slider">';
						echo '<span>';
							echo '<input class="range-slider__range" type="range" value="' . esc_attr( $this->value() ) . '"';
								$this->input_attrs();
								$this->link();
							echo '>';
							echo '<span class="range-slider__value">0</span>';
						echo '</span>';
					echo '</div>';
				echo '</label>';
			}
		}
	}



	/*====== Toggle ======*/
	if ( class_exists( 'WP_Customize_Control' ) ) {
		class Nucy_Customizer_Toggle_Control extends WP_Customize_Control {
			public $type = 'toggle';
			public function render_content() {
				echo '<label>';
					echo '<span class="customize-control-title">' . esc_html( $this->label ) . '</span>';
					if ( !empty( $this->description ) ) {
						echo '<span class="description customize-control-description">' . $this->description . '</span>';
					}
					echo '<div>';
						echo '<input id="nucy' . $this->instance_number . '" type="checkbox" class="tgl tgl-' . $this->type . '" value="' . esc_attr( $this->value() ) . '"';
							$this->link(); checked( $this->value() );
						echo '/>';
						echo '<label for="nucy' . $this->instance_number . '" class="tgl-btn"></label>';
					echo '</div>';
				echo '</label>';
			}
		}
	}



	/*====== Radio Image ======*/
	if ( class_exists( 'WP_Customize_Control' ) ) {
		class Nucy_Customize_Control_Radio_Image extends WP_Customize_Control {
			public $type = 'radio-image';

			public function enqueue() {
				wp_enqueue_script( 'jquery-ui-button' );
			}

			public function to_json() {
				parent::to_json();
				foreach ( $this->choices as $value => $args ) {
					$this->choices[ $value ]['url'] = esc_url( sprintf( $args['url'], get_template_directory_uri(), get_stylesheet_directory_uri() ) );
					$this->json['choices'] = $this->choices;
					$this->json['link'] = $this->get_link();
					$this->json['value'] = $this->value();
					$this->json['id'] = $this->id;
				}
			}

			public function content_template() { ?>
				<# if ( ! data.choices ) {
					return;
				} #>

				<# if ( data.label ) { #>
					<span class="customize-control-title">{{ data.label }}</span>
				<# } #>

				<# if ( data.description ) { #>
					<span class="description customize-control-description">{{{ data.description }}}</span>
				<# } #>

				<div class="buttonset">
					<# for ( key in data.choices ) { #>
						<input type="radio" value="{{ key }}" name="_customize-{{ data.type }}-{{ data.id }}" id="{{ data.id }}-{{ key }}" {{{ data.link }}} <# if ( key === data.value ) { #> checked="checked" <# } #> /> 
						<label for="{{ data.id }}-{{ key }}">
							<span class="screen-reader-text">{{ data.choices[ key ]['label'] }}</span>
							<img src="{{ data.choices[ key ]['url'] }}" alt="{{ data.choices[ key ]['label'] }}" />
						</label>
					<# } #>
				</div>
			<?php }
		}
	}



	/*====== Font List ======*/
	if ( ! function_exists( 'nucy_register_customizer_control_google_fonts' ) ) {
		function nucy_register_customizer_control_google_fonts( $wp_customize ) {
			if ( ! isset( $wp_customize ) ) {
				return;
			}

			class Nucy_Customize_Google_Fonts_Control extends WP_Customize_Control {
				public $type = 'google-fonts';
				public $api_key = null;
				public $amount = 'all';
				public $cache_time = 365;
				public $fonts = null;

				public function render_content() {
					if ( $this->fonts ) {
						if ( is_array( $this->fonts ) ) {
							$fonts = $this->fonts;
						} else {
							return;
						}
					} else {
						$fonts = $this->nucy_get_fonts();
						if ( ! $fonts ) {
							return;
						}
					}

					if ( ! empty( $this->label ) ) {
						echo '<span class="customize-control-title">' . esc_html( $this->label ) . '</span>';
					}

					if ( ! empty( $this->description ) ) {
						echo '<span class="description customize-control-description">' . esc_html( $this->description ) . '</span>';
					}

					echo '<select ';
						$this->link();
					echo '>';

					if ( $this->fonts ) {
						foreach ( $fonts as $font ) {
							printf( '<option value="%s" %s>%s</option>', $font, selected( $this->value(), $font ), $font );
						}
					} else {
						foreach ( $fonts as $font => $value ) {
							printf( '<option value="%s" %s>%s</option>', $value->family, selected( $this->value(), $value->family ), $value->family );
						}
					}

					echo '</select>';
				}

				private function nucy_get_fonts() {
					$api_key = $this->api_key;
					$cache_time = DAY_IN_SECONDS * $this->cache_time;

					if ( ! $api_key ) {
						return null;
					}

					if ( ! get_transient( 'nucy_google_fonts' ) ) {
						$cloud_url = 'https://www.googleapis.com/webfonts/v1/webfonts?key=' . $api_key;
						$local_url = get_template_directory_uri() . '/assets/fonts/google-fonts/google-fonts.json?ver=' . NUCY_VERSION;
						$cloud_data = wp_remote_get( $cloud_url, array( 'sslverify' => false ) );
						$local_data = wp_remote_get( $local_url, array( 'sslverify' => false ) );

						if ( ! is_wp_error( $cloud_data ) ) {
							$content = json_decode( $cloud_data['body'] );
							if ( isset( $content->error ) ) {
								if ( ! is_wp_error( $local_data ) ) {
									$content = json_decode( $local_data['body'] );
								} else {
									return null;
								}
							}
						} else {
							if ( ! is_wp_error( $local_data ) ) {
								$content = json_decode( $local_data['body'] );
							} else {
								return null;
							}
						}
						set_transient( 'nucy_google_fonts', $content, $cache_time );
					}

					if ( ! get_transient( 'nucy_popular_google_fonts' ) ) {
						$cloud_url = 'https://www.googleapis.com/webfonts/v1/webfonts?sort=popularity&key=' . $api_key;
						$local_url = get_template_directory_uri() . '/assets/fonts/google-fonts/google-fonts-popular.json?ver=' . NUCY_VERSION;
						$cloud_data = wp_remote_get( $cloud_url, array( 'sslverify' => false ) );
						$local_data = wp_remote_get( $local_url, array( 'sslverify' => false ) );

						if ( ! is_wp_error( $cloud_data ) ) {
							$content = json_decode( $cloud_data['body'] );
							if ( isset( $content->error ) ) {
								if ( ! is_wp_error( $local_data ) ) {
									$content = json_decode( $local_data['body'] );
								} else {
									return null;
								}
							}
						} else {
							if ( ! is_wp_error( $local_data ) ) {
								$content = json_decode( $local_data['body'] );
							} else {
								return null;
							}
						}

						set_transient( 'nucy_popular_google_fonts', $content, $cache_time );
					}

					if ( 'all' == $this->amount ) {
						$content = get_transient( 'nucy_google_fonts' );
						return $content->items;
					} else {
						$content = get_transient( 'nucy_popular_google_fonts' );
						return array_slice( $content->items, 0, $this->amount );
					}
				}
			}
		}
		add_action( 'customize_register', 'nucy_register_customizer_control_google_fonts', 0 );
	}



	/*====== Sidebar Dropdown ======*/
	if ( class_exists( 'WP_Customize_Control' ) ) {
		class Nucy_Sidebar_Dropdown_Custom_Control extends WP_Customize_Control {
			public $type = 'sidebar_dropdown';
			public function render_content() {
				echo '<label class="customize_dropdown_input">';
					echo '<span class="customize-control-title">' . esc_html( $this->label ) . '</span>';
					if ( ! empty( $this->description ) ) {
						echo '<span class="description customize-control-description">' . esc_html( $this->description ) . '</span>';
					}

					global $wp_registered_sidebars;
					echo '<select id="' . esc_attr( $this->id ) . '" name="' . esc_attr( $this->id ) . '" ';
						$this->link();
					echo ' >';
						$sidebar_shop = $wp_registered_sidebars;
						if ( is_array( $sidebar_shop ) && ! empty( $sidebar_shop ) ) {
							foreach ( $sidebar_shop as $sidebar ) {
								echo '<option value="' . esc_attr( $sidebar['id'] ) . '" ' . selected( $this->value(), $sidebar['name'], false ) . '>' . esc_html( $sidebar['name'] ) . '</option>';
							}
						}
					echo '</select>';
				echo '</label>';
			}
		}
	}



	/*====== Social Media ======*/
	function nucy_social_media_array_filter() {
		$social_sites = array(
			'facebook' => 'nucy_facebook_url',
			'twitter' => 'nucy_twitter_url',
			'google-plus' => 'nucy_googleplus_url',
			'pinterest' => 'nucy_pinterest_url',
			'linkedin' => 'nucy_linkedin_url',
			'youtube' => 'nucy_youtube_url',
			'vimeo' => 'nucy_vimeo_url',
			'tumblr' => 'nucy_tumblr_url',
			'instagram' => 'nucy_instagram_url',
			'flickr' => 'nucy_flickr_url',
			'dribbble' => 'nucy_dribbble_url',
			'reddit' => 'nucy_reddit_url',
			'soundcloud' => 'nucy_soundcloud_url',
			'spotify' => 'nucy_spotify_url',
			'yahoo' => 'nucy_yahoo_url',
			'behance' => 'nucy_behance_url',
			'codepen' => 'nucy_codepen_url',
			'delicious' => 'nucy_delicious_url',
			'stumbleupon' => 'nucy_stumbleupon_url',
			'deviantart' => 'nucy_deviantart_url',
			'digg' => 'nucy_digg_url',
			'github' => 'nucy_github_url',
			'medium' => 'nucy_medium_url',
			'steam' => 'nucy_steam_url',
			'vk' => 'nucy_vk_url',
			'500px' => 'nucy_500px_url',
			'foursquare' => 'nucy_foursquare_url',
			'slack' => 'nucy_slack_url',
			'whatsapp' => 'nucy_whatsapp_url',
			'skype' => 'nucy_skype_url',
			'twitch' => 'nucy_twitch_url',
			'paypal' => 'nucy_paypal_url',
			'rss' => 'nucy_rss_url',
			'custom-url' => 'nucy_custom_url',
		);
		return apply_filters( 'nucy_social_media_array_filter', $social_sites );
	}

	function nucy_social_share_array_filter() {
		$social_sites = array(
			'facebook' => 'nucy_facebook_share',
			'twitter' => 'nucy_twitter_share',
			'google-plus' => 'nucy_googleplus_share',
			'pinterest' => 'nucy_pinterest_share',
			'linkedin' => 'nucy_linkedin_share',
			'tumblr' => 'nucy_tumblr_share',
			'reddit' => 'nucy_reddit_share',
			'delicious' => 'nucy_delicious_share',
			'stumbleupon' => 'nucy_stumbleupon_share',
			'whatsapp' => 'nucy_whatsapp_share',
			'mail' => 'nucy_mail_share',
		);
		return apply_filters( 'nucy_social_share_array_filter', $social_sites );
	}